# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.hs2_highway_exemption import HS2HighwayExemption  # noqa: E501
from swagger_client.rest import ApiException


class TestHS2HighwayExemption(unittest.TestCase):
    """HS2HighwayExemption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHS2HighwayExemption(self):
        """Test HS2HighwayExemption"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.hs2_highway_exemption.HS2HighwayExemption()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
