# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.default_api import DefaultApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acknowledge_hs2_permit(self):
        """Test case for acknowledge_hs2_permit

        """
        pass

    def test_add_file_to_work(self):
        """Test case for add_file_to_work

        """
        pass

    def test_authenticate(self):
        """Test case for authenticate

        """
        pass

    def test_calculate_duration(self):
        """Test case for calculate_duration

        """
        pass

    def test_cancel_activity(self):
        """Test case for cancel_activity

        """
        pass

    def test_cancel_forward_plan(self):
        """Test case for cancel_forward_plan

        """
        pass

    def test_cancel_private_street_notice(self):
        """Test case for cancel_private_street_notice

        """
        pass

    def test_create_activity(self):
        """Test case for create_activity

        """
        pass

    def test_create_ancillary_info(self):
        """Test case for create_ancillary_info

        """
        pass

    def test_create_forward_plan(self):
        """Test case for create_forward_plan

        """
        pass

    def test_create_fpn(self):
        """Test case for create_fpn

        """
        pass

    def test_create_geographical_area(self):
        """Test case for create_geographical_area

        """
        pass

    def test_create_historic_fpn(self):
        """Test case for create_historic_fpn

        """
        pass

    def test_create_historic_inspection(self):
        """Test case for create_historic_inspection

        """
        pass

    def test_create_inspection(self):
        """Test case for create_inspection

        """
        pass

    def test_create_materials_classification(self):
        """Test case for create_materials_classification

        """
        pass

    def test_create_non_notifiable_site(self):
        """Test case for create_non_notifiable_site

        """
        pass

    def test_create_permit(self):
        """Test case for create_permit

        """
        pass

    def test_create_permit_alteration(self):
        """Test case for create_permit_alteration

        """
        pass

    def test_create_private_street_notice(self):
        """Test case for create_private_street_notice

        """
        pass

    def test_create_reinstatement(self):
        """Test case for create_reinstatement

        """
        pass

    def test_create_scheduled_inspection(self):
        """Test case for create_scheduled_inspection

        """
        pass

    def test_create_section58(self):
        """Test case for create_section58

        """
        pass

    def test_create_section74(self):
        """Test case for create_section74

        """
        pass

    def test_create_section81(self):
        """Test case for create_section81

        """
        pass

    def test_create_site(self):
        """Test case for create_site

        """
        pass

    def test_create_work(self):
        """Test case for create_work

        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        """
        pass

    def test_delete_fpn(self):
        """Test case for delete_fpn

        """
        pass

    def test_delete_inspection(self):
        """Test case for delete_inspection

        """
        pass

    def test_delete_reinstatement(self):
        """Test case for delete_reinstatement

        """
        pass

    def test_delete_scheduled_inspection(self):
        """Test case for delete_scheduled_inspection

        """
        pass

    def test_duration_challenge_non_acceptance_response(self):
        """Test case for duration_challenge_non_acceptance_response

        """
        pass

    def test_duration_challenge_review(self):
        """Test case for duration_challenge_review

        """
        pass

    def test_get_activity(self):
        """Test case for get_activity

        """
        pass

    def test_get_ancillary_info(self):
        """Test case for get_ancillary_info

        """
        pass

    def test_get_comment(self):
        """Test case for get_comment

        """
        pass

    def test_get_earliest_permit(self):
        """Test case for get_earliest_permit

        """
        pass

    def test_get_fee_matrix(self):
        """Test case for get_fee_matrix

        """
        pass

    def test_get_file(self):
        """Test case for get_file

        """
        pass

    def test_get_forward_plan(self):
        """Test case for get_forward_plan

        """
        pass

    def test_get_fpn(self):
        """Test case for get_fpn

        """
        pass

    def test_get_inspection(self):
        """Test case for get_inspection

        """
        pass

    def test_get_material_classification(self):
        """Test case for get_material_classification

        """
        pass

    def test_get_non_compliance(self):
        """Test case for get_non_compliance

        """
        pass

    def test_get_permit(self):
        """Test case for get_permit

        """
        pass

    def test_get_permit_alteration(self):
        """Test case for get_permit_alteration

        """
        pass

    def test_get_private_street_notice(self):
        """Test case for get_private_street_notice

        """
        pass

    def test_get_section58(self):
        """Test case for get_section58

        """
        pass

    def test_get_section74(self):
        """Test case for get_section74

        """
        pass

    def test_get_section81(self):
        """Test case for get_section81

        """
        pass

    def test_get_site(self):
        """Test case for get_site

        """
        pass

    def test_get_work(self):
        """Test case for get_work

        """
        pass

    def test_get_work_category(self):
        """Test case for get_work_category

        """
        pass

    def test_get_work_history(self):
        """Test case for get_work_history

        """
        pass

    def test_impose_change(self):
        """Test case for impose_change

        """
        pass

    def test_link_permit_to_non_compliance(self):
        """Test case for link_permit_to_non_compliance

        """
        pass

    def test_link_section81_to_permit(self):
        """Test case for link_section81_to_permit

        """
        pass

    def test_mark_comment_as_read(self):
        """Test case for mark_comment_as_read

        """
        pass

    def test_mark_permit_as_under_assessment(self):
        """Test case for mark_permit_as_under_assessment

        """
        pass

    def test_post_comment(self):
        """Test case for post_comment

        """
        pass

    def test_reassign_section81(self):
        """Test case for reassign_section81

        """
        pass

    def test_remove_ancillary_info(self):
        """Test case for remove_ancillary_info

        """
        pass

    def test_revert_actual_start_date(self):
        """Test case for revert_actual_start_date

        """
        pass

    def test_revert_actual_stop_date(self):
        """Test case for revert_actual_stop_date

        """
        pass

    def test_subsume_site(self):
        """Test case for subsume_site

        """
        pass

    def test_unlink_section81_from_permit(self):
        """Test case for unlink_section81_from_permit

        """
        pass

    def test_update_activity(self):
        """Test case for update_activity

        """
        pass

    def test_update_actual_start_date(self):
        """Test case for update_actual_start_date

        """
        pass

    def test_update_actual_stop_date(self):
        """Test case for update_actual_stop_date

        """
        pass

    def test_update_assessment_status(self):
        """Test case for update_assessment_status

        """
        pass

    def test_update_current_traffic_management_type(self):
        """Test case for update_current_traffic_management_type

        """
        pass

    def test_update_excavation_carried_out(self):
        """Test case for update_excavation_carried_out

        """
        pass

    def test_update_final_reinstatement(self):
        """Test case for update_final_reinstatement

        """
        pass

    def test_update_forward_plan(self):
        """Test case for update_forward_plan

        """
        pass

    def test_update_fpn_status(self):
        """Test case for update_fpn_status

        """
        pass

    def test_update_geographical_area(self):
        """Test case for update_geographical_area

        """
        pass

    def test_update_inspection_outcome_status(self):
        """Test case for update_inspection_outcome_status

        """
        pass

    def test_update_non_compliance_status(self):
        """Test case for update_non_compliance_status

        """
        pass

    def test_update_permit_alteration_status(self):
        """Test case for update_permit_alteration_status

        """
        pass

    def test_update_permit_discount(self):
        """Test case for update_permit_discount

        """
        pass

    def test_update_permit_duration_challenge_non_acceptance_response(self):
        """Test case for update_permit_duration_challenge_non_acceptance_response

        """
        pass

    def test_update_permit_duration_challenge_review(self):
        """Test case for update_permit_duration_challenge_review

        """
        pass

    def test_update_permit_lane_rental_assessment(self):
        """Test case for update_permit_lane_rental_assessment

        """
        pass

    def test_update_permit_status(self):
        """Test case for update_permit_status

        """
        pass

    def test_update_section58_status(self):
        """Test case for update_section58_status

        """
        pass

    def test_update_section74_ha_status(self):
        """Test case for update_section74_ha_status

        """
        pass

    def test_update_section74_promoter_status(self):
        """Test case for update_section74_promoter_status

        """
        pass

    def test_update_section81_status(self):
        """Test case for update_section81_status

        """
        pass

    def test_upload_file(self):
        """Test case for upload_file

        """
        pass

    def test_withdraw_inspection(self):
        """Test case for withdraw_inspection

        """
        pass


if __name__ == '__main__':
    unittest.main()
