# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitAlterationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'permit_alteration_reference_number': 'str',
        'date_created': 'datetime',
        'deadline_date': 'datetime',
        'alteration_status': 'AlterationStatusResponse',
        'alteration_status_string': 'str',
        'alteration_type': 'AlterationTypeResponse',
        'alteration_type_string': 'str',
        'permit_status': 'AllOfPermitAlterationResponsePermitStatus',
        'permit_status_string': 'str',
        'assessment_discount': 'float',
        'assessment_comments': 'str',
        'permit_alteration_reason': 'str',
        'original': 'PermitResponse',
        'proposed': 'PermitResponse',
        'duration_challenge_review_status': 'AllOfPermitAlterationResponseDurationChallengeReviewStatus',
        'duration_challenge_review_status_string': 'str',
        'duration_challenge_reason_for_non_acceptance': 'str',
        'duration_challenge_review_update_date': 'datetime',
        'duration_challenge_non_acceptance_response_status': 'AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus',
        'duration_challenge_non_acceptance_response_status_string': 'str',
        'duration_challenge_non_acceptance_response_details': 'str',
        'duration_challenge_non_acceptance_response_update_date': 'datetime',
        'duration_challenge_non_acceptance_response_new_reasonable_period_end_date': 'datetime',
        'duration_challenge_non_acceptance_response_old_reasonable_period_end_date': 'datetime',
        'duration_challenge_follow_up_review_complete': 'bool'
    }

    attribute_map = {
        'permit_alteration_reference_number': 'permit_alteration_reference_number',
        'date_created': 'date_created',
        'deadline_date': 'deadline_date',
        'alteration_status': 'alteration_status',
        'alteration_status_string': 'alteration_status_string',
        'alteration_type': 'alteration_type',
        'alteration_type_string': 'alteration_type_string',
        'permit_status': 'permit_status',
        'permit_status_string': 'permit_status_string',
        'assessment_discount': 'assessment_discount',
        'assessment_comments': 'assessment_comments',
        'permit_alteration_reason': 'permit_alteration_reason',
        'original': 'original',
        'proposed': 'proposed',
        'duration_challenge_review_status': 'duration_challenge_review_status',
        'duration_challenge_review_status_string': 'duration_challenge_review_status_string',
        'duration_challenge_reason_for_non_acceptance': 'duration_challenge_reason_for_non_acceptance',
        'duration_challenge_review_update_date': 'duration_challenge_review_update_date',
        'duration_challenge_non_acceptance_response_status': 'duration_challenge_non_acceptance_response_status',
        'duration_challenge_non_acceptance_response_status_string': 'duration_challenge_non_acceptance_response_status_string',
        'duration_challenge_non_acceptance_response_details': 'duration_challenge_non_acceptance_response_details',
        'duration_challenge_non_acceptance_response_update_date': 'duration_challenge_non_acceptance_response_update_date',
        'duration_challenge_non_acceptance_response_new_reasonable_period_end_date': 'duration_challenge_non_acceptance_response_new_reasonable_period_end_date',
        'duration_challenge_non_acceptance_response_old_reasonable_period_end_date': 'duration_challenge_non_acceptance_response_old_reasonable_period_end_date',
        'duration_challenge_follow_up_review_complete': 'duration_challenge_follow_up_review_complete'
    }

    def __init__(self, permit_alteration_reference_number=None, date_created=None, deadline_date=None, alteration_status=None, alteration_status_string=None, alteration_type=None, alteration_type_string=None, permit_status=None, permit_status_string=None, assessment_discount=None, assessment_comments=None, permit_alteration_reason=None, original=None, proposed=None, duration_challenge_review_status=None, duration_challenge_review_status_string=None, duration_challenge_reason_for_non_acceptance=None, duration_challenge_review_update_date=None, duration_challenge_non_acceptance_response_status=None, duration_challenge_non_acceptance_response_status_string=None, duration_challenge_non_acceptance_response_details=None, duration_challenge_non_acceptance_response_update_date=None, duration_challenge_non_acceptance_response_new_reasonable_period_end_date=None, duration_challenge_non_acceptance_response_old_reasonable_period_end_date=None, duration_challenge_follow_up_review_complete=None):  # noqa: E501
        """PermitAlterationResponse - a model defined in Swagger"""  # noqa: E501
        self._permit_alteration_reference_number = None
        self._date_created = None
        self._deadline_date = None
        self._alteration_status = None
        self._alteration_status_string = None
        self._alteration_type = None
        self._alteration_type_string = None
        self._permit_status = None
        self._permit_status_string = None
        self._assessment_discount = None
        self._assessment_comments = None
        self._permit_alteration_reason = None
        self._original = None
        self._proposed = None
        self._duration_challenge_review_status = None
        self._duration_challenge_review_status_string = None
        self._duration_challenge_reason_for_non_acceptance = None
        self._duration_challenge_review_update_date = None
        self._duration_challenge_non_acceptance_response_status = None
        self._duration_challenge_non_acceptance_response_status_string = None
        self._duration_challenge_non_acceptance_response_details = None
        self._duration_challenge_non_acceptance_response_update_date = None
        self._duration_challenge_non_acceptance_response_new_reasonable_period_end_date = None
        self._duration_challenge_non_acceptance_response_old_reasonable_period_end_date = None
        self._duration_challenge_follow_up_review_complete = None
        self.discriminator = None
        self.permit_alteration_reference_number = permit_alteration_reference_number
        self.date_created = date_created
        self.deadline_date = deadline_date
        self.alteration_status = alteration_status
        self.alteration_status_string = alteration_status_string
        self.alteration_type = alteration_type
        self.alteration_type_string = alteration_type_string
        if permit_status is not None:
            self.permit_status = permit_status
        if permit_status_string is not None:
            self.permit_status_string = permit_status_string
        if assessment_discount is not None:
            self.assessment_discount = assessment_discount
        if assessment_comments is not None:
            self.assessment_comments = assessment_comments
        self.permit_alteration_reason = permit_alteration_reason
        self.original = original
        self.proposed = proposed
        if duration_challenge_review_status is not None:
            self.duration_challenge_review_status = duration_challenge_review_status
        if duration_challenge_review_status_string is not None:
            self.duration_challenge_review_status_string = duration_challenge_review_status_string
        if duration_challenge_reason_for_non_acceptance is not None:
            self.duration_challenge_reason_for_non_acceptance = duration_challenge_reason_for_non_acceptance
        if duration_challenge_review_update_date is not None:
            self.duration_challenge_review_update_date = duration_challenge_review_update_date
        if duration_challenge_non_acceptance_response_status is not None:
            self.duration_challenge_non_acceptance_response_status = duration_challenge_non_acceptance_response_status
        if duration_challenge_non_acceptance_response_status_string is not None:
            self.duration_challenge_non_acceptance_response_status_string = duration_challenge_non_acceptance_response_status_string
        if duration_challenge_non_acceptance_response_details is not None:
            self.duration_challenge_non_acceptance_response_details = duration_challenge_non_acceptance_response_details
        if duration_challenge_non_acceptance_response_update_date is not None:
            self.duration_challenge_non_acceptance_response_update_date = duration_challenge_non_acceptance_response_update_date
        if duration_challenge_non_acceptance_response_new_reasonable_period_end_date is not None:
            self.duration_challenge_non_acceptance_response_new_reasonable_period_end_date = duration_challenge_non_acceptance_response_new_reasonable_period_end_date
        if duration_challenge_non_acceptance_response_old_reasonable_period_end_date is not None:
            self.duration_challenge_non_acceptance_response_old_reasonable_period_end_date = duration_challenge_non_acceptance_response_old_reasonable_period_end_date
        if duration_challenge_follow_up_review_complete is not None:
            self.duration_challenge_follow_up_review_complete = duration_challenge_follow_up_review_complete

    @property
    def permit_alteration_reference_number(self):
        """Gets the permit_alteration_reference_number of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_alteration_reference_number of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_alteration_reference_number

    @permit_alteration_reference_number.setter
    def permit_alteration_reference_number(self, permit_alteration_reference_number):
        """Sets the permit_alteration_reference_number of this PermitAlterationResponse.


        :param permit_alteration_reference_number: The permit_alteration_reference_number of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if permit_alteration_reference_number is None:
            raise ValueError("Invalid value for `permit_alteration_reference_number`, must not be `None`")  # noqa: E501

        self._permit_alteration_reference_number = permit_alteration_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this PermitAlterationResponse.  # noqa: E501


        :return: The date_created of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this PermitAlterationResponse.


        :param date_created: The date_created of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def deadline_date(self):
        """Gets the deadline_date of this PermitAlterationResponse.  # noqa: E501


        :return: The deadline_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._deadline_date

    @deadline_date.setter
    def deadline_date(self, deadline_date):
        """Sets the deadline_date of this PermitAlterationResponse.


        :param deadline_date: The deadline_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """
        if deadline_date is None:
            raise ValueError("Invalid value for `deadline_date`, must not be `None`")  # noqa: E501

        self._deadline_date = deadline_date

    @property
    def alteration_status(self):
        """Gets the alteration_status of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AlterationStatusResponse
        """
        return self._alteration_status

    @alteration_status.setter
    def alteration_status(self, alteration_status):
        """Sets the alteration_status of this PermitAlterationResponse.


        :param alteration_status: The alteration_status of this PermitAlterationResponse.  # noqa: E501
        :type: AlterationStatusResponse
        """
        if alteration_status is None:
            raise ValueError("Invalid value for `alteration_status`, must not be `None`")  # noqa: E501

        self._alteration_status = alteration_status

    @property
    def alteration_status_string(self):
        """Gets the alteration_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._alteration_status_string

    @alteration_status_string.setter
    def alteration_status_string(self, alteration_status_string):
        """Sets the alteration_status_string of this PermitAlterationResponse.


        :param alteration_status_string: The alteration_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if alteration_status_string is None:
            raise ValueError("Invalid value for `alteration_status_string`, must not be `None`")  # noqa: E501

        self._alteration_status_string = alteration_status_string

    @property
    def alteration_type(self):
        """Gets the alteration_type of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_type of this PermitAlterationResponse.  # noqa: E501
        :rtype: AlterationTypeResponse
        """
        return self._alteration_type

    @alteration_type.setter
    def alteration_type(self, alteration_type):
        """Sets the alteration_type of this PermitAlterationResponse.


        :param alteration_type: The alteration_type of this PermitAlterationResponse.  # noqa: E501
        :type: AlterationTypeResponse
        """
        if alteration_type is None:
            raise ValueError("Invalid value for `alteration_type`, must not be `None`")  # noqa: E501

        self._alteration_type = alteration_type

    @property
    def alteration_type_string(self):
        """Gets the alteration_type_string of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_type_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._alteration_type_string

    @alteration_type_string.setter
    def alteration_type_string(self, alteration_type_string):
        """Sets the alteration_type_string of this PermitAlterationResponse.


        :param alteration_type_string: The alteration_type_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if alteration_type_string is None:
            raise ValueError("Invalid value for `alteration_type_string`, must not be `None`")  # noqa: E501

        self._alteration_type_string = alteration_type_string

    @property
    def permit_status(self):
        """Gets the permit_status of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AllOfPermitAlterationResponsePermitStatus
        """
        return self._permit_status

    @permit_status.setter
    def permit_status(self, permit_status):
        """Sets the permit_status of this PermitAlterationResponse.


        :param permit_status: The permit_status of this PermitAlterationResponse.  # noqa: E501
        :type: AllOfPermitAlterationResponsePermitStatus
        """

        self._permit_status = permit_status

    @property
    def permit_status_string(self):
        """Gets the permit_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_status_string

    @permit_status_string.setter
    def permit_status_string(self, permit_status_string):
        """Sets the permit_status_string of this PermitAlterationResponse.


        :param permit_status_string: The permit_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._permit_status_string = permit_status_string

    @property
    def assessment_discount(self):
        """Gets the assessment_discount of this PermitAlterationResponse.  # noqa: E501


        :return: The assessment_discount of this PermitAlterationResponse.  # noqa: E501
        :rtype: float
        """
        return self._assessment_discount

    @assessment_discount.setter
    def assessment_discount(self, assessment_discount):
        """Sets the assessment_discount of this PermitAlterationResponse.


        :param assessment_discount: The assessment_discount of this PermitAlterationResponse.  # noqa: E501
        :type: float
        """

        self._assessment_discount = assessment_discount

    @property
    def assessment_comments(self):
        """Gets the assessment_comments of this PermitAlterationResponse.  # noqa: E501


        :return: The assessment_comments of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._assessment_comments

    @assessment_comments.setter
    def assessment_comments(self, assessment_comments):
        """Sets the assessment_comments of this PermitAlterationResponse.


        :param assessment_comments: The assessment_comments of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._assessment_comments = assessment_comments

    @property
    def permit_alteration_reason(self):
        """Gets the permit_alteration_reason of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_alteration_reason of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_alteration_reason

    @permit_alteration_reason.setter
    def permit_alteration_reason(self, permit_alteration_reason):
        """Sets the permit_alteration_reason of this PermitAlterationResponse.


        :param permit_alteration_reason: The permit_alteration_reason of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if permit_alteration_reason is None:
            raise ValueError("Invalid value for `permit_alteration_reason`, must not be `None`")  # noqa: E501

        self._permit_alteration_reason = permit_alteration_reason

    @property
    def original(self):
        """Gets the original of this PermitAlterationResponse.  # noqa: E501


        :return: The original of this PermitAlterationResponse.  # noqa: E501
        :rtype: PermitResponse
        """
        return self._original

    @original.setter
    def original(self, original):
        """Sets the original of this PermitAlterationResponse.


        :param original: The original of this PermitAlterationResponse.  # noqa: E501
        :type: PermitResponse
        """
        if original is None:
            raise ValueError("Invalid value for `original`, must not be `None`")  # noqa: E501

        self._original = original

    @property
    def proposed(self):
        """Gets the proposed of this PermitAlterationResponse.  # noqa: E501


        :return: The proposed of this PermitAlterationResponse.  # noqa: E501
        :rtype: PermitResponse
        """
        return self._proposed

    @proposed.setter
    def proposed(self, proposed):
        """Sets the proposed of this PermitAlterationResponse.


        :param proposed: The proposed of this PermitAlterationResponse.  # noqa: E501
        :type: PermitResponse
        """
        if proposed is None:
            raise ValueError("Invalid value for `proposed`, must not be `None`")  # noqa: E501

        self._proposed = proposed

    @property
    def duration_challenge_review_status(self):
        """Gets the duration_challenge_review_status of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_review_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AllOfPermitAlterationResponseDurationChallengeReviewStatus
        """
        return self._duration_challenge_review_status

    @duration_challenge_review_status.setter
    def duration_challenge_review_status(self, duration_challenge_review_status):
        """Sets the duration_challenge_review_status of this PermitAlterationResponse.


        :param duration_challenge_review_status: The duration_challenge_review_status of this PermitAlterationResponse.  # noqa: E501
        :type: AllOfPermitAlterationResponseDurationChallengeReviewStatus
        """

        self._duration_challenge_review_status = duration_challenge_review_status

    @property
    def duration_challenge_review_status_string(self):
        """Gets the duration_challenge_review_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_review_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_review_status_string

    @duration_challenge_review_status_string.setter
    def duration_challenge_review_status_string(self, duration_challenge_review_status_string):
        """Sets the duration_challenge_review_status_string of this PermitAlterationResponse.


        :param duration_challenge_review_status_string: The duration_challenge_review_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_review_status_string = duration_challenge_review_status_string

    @property
    def duration_challenge_reason_for_non_acceptance(self):
        """Gets the duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_reason_for_non_acceptance

    @duration_challenge_reason_for_non_acceptance.setter
    def duration_challenge_reason_for_non_acceptance(self, duration_challenge_reason_for_non_acceptance):
        """Sets the duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.


        :param duration_challenge_reason_for_non_acceptance: The duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_reason_for_non_acceptance = duration_challenge_reason_for_non_acceptance

    @property
    def duration_challenge_review_update_date(self):
        """Gets the duration_challenge_review_update_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_review_update_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_review_update_date

    @duration_challenge_review_update_date.setter
    def duration_challenge_review_update_date(self, duration_challenge_review_update_date):
        """Sets the duration_challenge_review_update_date of this PermitAlterationResponse.


        :param duration_challenge_review_update_date: The duration_challenge_review_update_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_review_update_date = duration_challenge_review_update_date

    @property
    def duration_challenge_non_acceptance_response_status(self):
        """Gets the duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus
        """
        return self._duration_challenge_non_acceptance_response_status

    @duration_challenge_non_acceptance_response_status.setter
    def duration_challenge_non_acceptance_response_status(self, duration_challenge_non_acceptance_response_status):
        """Sets the duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_status: The duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.  # noqa: E501
        :type: AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus
        """

        self._duration_challenge_non_acceptance_response_status = duration_challenge_non_acceptance_response_status

    @property
    def duration_challenge_non_acceptance_response_status_string(self):
        """Gets the duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_non_acceptance_response_status_string

    @duration_challenge_non_acceptance_response_status_string.setter
    def duration_challenge_non_acceptance_response_status_string(self, duration_challenge_non_acceptance_response_status_string):
        """Sets the duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_status_string: The duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_non_acceptance_response_status_string = duration_challenge_non_acceptance_response_status_string

    @property
    def duration_challenge_non_acceptance_response_details(self):
        """Gets the duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_non_acceptance_response_details

    @duration_challenge_non_acceptance_response_details.setter
    def duration_challenge_non_acceptance_response_details(self, duration_challenge_non_acceptance_response_details):
        """Sets the duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_details: The duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_non_acceptance_response_details = duration_challenge_non_acceptance_response_details

    @property
    def duration_challenge_non_acceptance_response_update_date(self):
        """Gets the duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_non_acceptance_response_update_date

    @duration_challenge_non_acceptance_response_update_date.setter
    def duration_challenge_non_acceptance_response_update_date(self, duration_challenge_non_acceptance_response_update_date):
        """Sets the duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_update_date: The duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_non_acceptance_response_update_date = duration_challenge_non_acceptance_response_update_date

    @property
    def duration_challenge_non_acceptance_response_new_reasonable_period_end_date(self):
        """Gets the duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_non_acceptance_response_new_reasonable_period_end_date

    @duration_challenge_non_acceptance_response_new_reasonable_period_end_date.setter
    def duration_challenge_non_acceptance_response_new_reasonable_period_end_date(self, duration_challenge_non_acceptance_response_new_reasonable_period_end_date):
        """Sets the duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_new_reasonable_period_end_date: The duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_non_acceptance_response_new_reasonable_period_end_date = duration_challenge_non_acceptance_response_new_reasonable_period_end_date

    @property
    def duration_challenge_non_acceptance_response_old_reasonable_period_end_date(self):
        """Gets the duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_non_acceptance_response_old_reasonable_period_end_date

    @duration_challenge_non_acceptance_response_old_reasonable_period_end_date.setter
    def duration_challenge_non_acceptance_response_old_reasonable_period_end_date(self, duration_challenge_non_acceptance_response_old_reasonable_period_end_date):
        """Sets the duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_old_reasonable_period_end_date: The duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_non_acceptance_response_old_reasonable_period_end_date = duration_challenge_non_acceptance_response_old_reasonable_period_end_date

    @property
    def duration_challenge_follow_up_review_complete(self):
        """Gets the duration_challenge_follow_up_review_complete of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_follow_up_review_complete of this PermitAlterationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._duration_challenge_follow_up_review_complete

    @duration_challenge_follow_up_review_complete.setter
    def duration_challenge_follow_up_review_complete(self, duration_challenge_follow_up_review_complete):
        """Sets the duration_challenge_follow_up_review_complete of this PermitAlterationResponse.


        :param duration_challenge_follow_up_review_complete: The duration_challenge_follow_up_review_complete of this PermitAlterationResponse.  # noqa: E501
        :type: bool
        """

        self._duration_challenge_follow_up_review_complete = duration_challenge_follow_up_review_complete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitAlterationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitAlterationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
