# coding: utf-8

# flake8: noqa

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from .api import DefaultApi
# import ApiClient
from .api_client import ApiClient
from .configuration import Configuration
# import models into sdk package
from .models.asd_code import ASDCode
from .models.asd_code_response import ASDCodeResponse
from .models.asd_periodicity_code import ASDPeriodicityCode
from .models.asd_periodicity_code_response import ASDPeriodicityCodeResponse
from .models.activity_activity_type import ActivityActivityType
from .models.activity_activity_type_response import ActivityActivityTypeResponse
from .models.activity_cancel_request import ActivityCancelRequest
from .models.activity_create_request import ActivityCreateRequest
from .models.activity_create_response import ActivityCreateResponse
from .models.activity_response import ActivityResponse
from .models.activity_type import ActivityType
from .models.activity_type_response import ActivityTypeResponse
from .models.activity_update_request import ActivityUpdateRequest
from .models.add_file_to_work_request import AddFileToWorkRequest
from .models.all_of_forward_plan_create_request_hs2_highway_exemption import AllOfForwardPlanCreateRequestHs2HighwayExemption
from .models.all_of_forward_plan_create_request_hs2_work_type import AllOfForwardPlanCreateRequestHs2WorkType
from .models.all_of_forward_plan_create_request_traffic_management_type import AllOfForwardPlanCreateRequestTrafficManagementType
from .models.all_of_forward_plan_response_hs2_highway_exemption import AllOfForwardPlanResponseHs2HighwayExemption
from .models.all_of_forward_plan_response_hs2_works_type import AllOfForwardPlanResponseHs2WorksType
from .models.all_of_forward_plan_response_traffic_management_type import AllOfForwardPlanResponseTrafficManagementType
from .models.all_of_forward_plan_update_request_traffic_management_type import AllOfForwardPlanUpdateRequestTrafficManagementType
from .models.all_of_historic_inspection_create_request_defect_fixed_on_site import AllOfHistoricInspectionCreateRequestDefectFixedOnSite
from .models.all_of_historic_inspection_create_request_inspection_category import AllOfHistoricInspectionCreateRequestInspectionCategory
from .models.all_of_historic_inspection_create_request_reinspection_category import AllOfHistoricInspectionCreateRequestReinspectionCategory
from .models.all_of_historic_inspection_create_request_reinspection_type import AllOfHistoricInspectionCreateRequestReinspectionType
from .models.all_of_inspection_create_request_defect_fixed_on_site import AllOfInspectionCreateRequestDefectFixedOnSite
from .models.all_of_inspection_create_request_inspection_category import AllOfInspectionCreateRequestInspectionCategory
from .models.all_of_inspection_create_request_reinspection_category import AllOfInspectionCreateRequestReinspectionCategory
from .models.all_of_inspection_create_request_reinspection_type import AllOfInspectionCreateRequestReinspectionType
from .models.all_of_inspection_response_defect_fixed_on_site import AllOfInspectionResponseDefectFixedOnSite
from .models.all_of_inspection_response_ha_response_status import AllOfInspectionResponseHaResponseStatus
from .models.all_of_inspection_response_inspection_category import AllOfInspectionResponseInspectionCategory
from .models.all_of_inspection_response_inspection_reason_for_withdrawal import AllOfInspectionResponseInspectionReasonForWithdrawal
from .models.all_of_inspection_response_promoter_response_status import AllOfInspectionResponsePromoterResponseStatus
from .models.all_of_inspection_summary_response_inspection_category import AllOfInspectionSummaryResponseInspectionCategory
from .models.all_of_inspection_summary_response_inspection_outcome import AllOfInspectionSummaryResponseInspectionOutcome
from .models.all_of_material_classification_response_file import AllOfMaterialClassificationResponseFile
from .models.all_of_non_compliance_response_jsm_status import AllOfNonComplianceResponseJsmStatus
from .models.all_of_non_compliance_response_promoter_response_status import AllOfNonComplianceResponsePromoterResponseStatus
from .models.all_of_permit_asd_response_special_desig_periodicity_code import AllOfPermitASDResponseSpecialDesigPeriodicityCode
from .models.all_of_permit_asd_special_desig_periodicity_code import AllOfPermitASDSpecialDesigPeriodicityCode
from .models.all_of_permit_alteration_create_request_collaboration_type import AllOfPermitAlterationCreateRequestCollaborationType
from .models.all_of_permit_alteration_response_duration_challenge_non_acceptance_response_status import AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus
from .models.all_of_permit_alteration_response_duration_challenge_review_status import AllOfPermitAlterationResponseDurationChallengeReviewStatus
from .models.all_of_permit_alteration_response_permit_status import AllOfPermitAlterationResponsePermitStatus
from .models.all_of_permit_create_request_collaboration_type import AllOfPermitCreateRequestCollaborationType
from .models.all_of_permit_create_request_hs2_highway_exemption import AllOfPermitCreateRequestHs2HighwayExemption
from .models.all_of_permit_lane_rental_assessment_update_request_charge_band import AllOfPermitLaneRentalAssessmentUpdateRequestChargeBand
from .models.all_of_permit_response_assessment_status import AllOfPermitResponseAssessmentStatus
from .models.all_of_permit_response_collaboration_type import AllOfPermitResponseCollaborationType
from .models.all_of_permit_response_current_traffic_management_type import AllOfPermitResponseCurrentTrafficManagementType
from .models.all_of_permit_response_duration_challenge_non_acceptance_response_status import AllOfPermitResponseDurationChallengeNonAcceptanceResponseStatus
from .models.all_of_permit_response_duration_challenge_review_status import AllOfPermitResponseDurationChallengeReviewStatus
from .models.all_of_permit_response_hs2_highway_exemption import AllOfPermitResponseHs2HighwayExemption
from .models.all_of_permit_response_lane_rental_assessment_charge_band import AllOfPermitResponseLaneRentalAssessmentChargeBand
from .models.all_of_permit_response_lane_rental_assessment_outcome import AllOfPermitResponseLaneRentalAssessmentOutcome
from .models.all_of_permit_response_linked_section81 import AllOfPermitResponseLinkedSection81
from .models.all_of_permit_response_permit_cancellation_reason import AllOfPermitResponsePermitCancellationReason
from .models.all_of_permit_status_update_request_permit_cancellation_reason import AllOfPermitStatusUpdateRequestPermitCancellationReason
from .models.all_of_scheduled_inspection_create_request_scheduled_inspection_category import AllOfScheduledInspectionCreateRequestScheduledInspectionCategory
from .models.all_of_section74_response_promoter_status import AllOfSection74ResponsePromoterStatus
from .models.all_of_section81_create_request_section81_severity import AllOfSection81CreateRequestSection81Severity
from .models.all_of_section81_response_linked_permit import AllOfSection81ResponseLinkedPermit
from .models.all_of_section81_response_promoter_status import AllOfSection81ResponsePromoterStatus
from .models.all_of_section81_response_section81_work_type import AllOfSection81ResponseSection81WorkType
from .models.all_of_section81_status_update_request_work_type import AllOfSection81StatusUpdateRequestWorkType
from .models.all_of_work_create_request_collaboration_type import AllOfWorkCreateRequestCollaborationType
from .models.all_of_work_create_request_hs2_highway_exemption import AllOfWorkCreateRequestHs2HighwayExemption
from .models.all_of_work_response_active_permit import AllOfWorkResponseActivePermit
from .models.all_of_work_response_forward_plan import AllOfWorkResponseForwardPlan
from .models.all_of_work_response_private_street_notice import AllOfWorkResponsePrivateStreetNotice
from .models.all_of_work_response_promoter_organisation_industry_type import AllOfWorkResponsePromoterOrganisationIndustryType
from .models.all_of_work_response_section81 import AllOfWorkResponseSection81
from .models.alteration_status import AlterationStatus
from .models.alteration_status_response import AlterationStatusResponse
from .models.alteration_type_response import AlterationTypeResponse
from .models.ancillary_info_response import AncillaryInfoResponse
from .models.ancillary_info_status_response import AncillaryInfoStatusResponse
from .models.ancillary_info_summary_response import AncillaryInfoSummaryResponse
from .models.ancillary_info_type import AncillaryInfoType
from .models.ancillary_info_type_response import AncillaryInfoTypeResponse
from .models.application_type import ApplicationType
from .models.application_type_response import ApplicationTypeResponse
from .models.assessment_status import AssessmentStatus
from .models.assessment_status_response import AssessmentStatusResponse
from .models.audit_event import AuditEvent
from .models.authentication_request import AuthenticationRequest
from .models.authentication_response import AuthenticationResponse
from .models.close_footpath import CloseFootpath
from .models.close_footpath_response import CloseFootpathResponse
from .models.close_footway import CloseFootway
from .models.close_footway_response import CloseFootwayResponse
from .models.collaboration_type import CollaborationType
from .models.collaboration_type_response import CollaborationTypeResponse
from .models.comment_create_request import CommentCreateRequest
from .models.comment_create_response import CommentCreateResponse
from .models.comment_read_request import CommentReadRequest
from .models.comment_response import CommentResponse
from .models.comment_topic import CommentTopic
from .models.comment_topic_response import CommentTopicResponse
from .models.create_ancillary_info_request import CreateAncillaryInfoRequest
from .models.create_ancillary_info_response import CreateAncillaryInfoResponse
from .models.current_traffic_management_type_request import CurrentTrafficManagementTypeRequest
from .models.defect_fixed_onsite import DefectFixedOnsite
from .models.defect_fixed_onsite_response import DefectFixedOnsiteResponse
from .models.duration_calculation_response import DurationCalculationResponse
from .models.duration_challenge_non_acceptance_response_status import DurationChallengeNonAcceptanceResponseStatus
from .models.duration_challenge_non_acceptance_response_status_response import DurationChallengeNonAcceptanceResponseStatusResponse
from .models.duration_challenge_review_status import DurationChallengeReviewStatus
from .models.duration_challenge_review_status_response import DurationChallengeReviewStatusResponse
from .models.excavation_carried_out_update_request import ExcavationCarriedOutUpdateRequest
from .models.fpn_create_request import FPNCreateRequest
from .models.fpn_create_response import FPNCreateResponse
from .models.fpn_response import FPNResponse
from .models.fpn_status import FPNStatus
from .models.fpn_status_response import FPNStatusResponse
from .models.fpn_status_update_request import FPNStatusUpdateRequest
from .models.fpn_summary_response import FPNSummaryResponse
from .models.failure_reason import FailureReason
from .models.failure_reason_details import FailureReasonDetails
from .models.failure_reason_details_response import FailureReasonDetailsResponse
from .models.failure_reason_response import FailureReasonResponse
from .models.fee_matrix_request import FeeMatrixRequest
from .models.fee_matrix_response import FeeMatrixResponse
from .models.file_response import FileResponse
from .models.file_summary_response import FileSummaryResponse
from .models.files_body import FilesBody
from .models.final_reinstatement_update_request import FinalReinstatementUpdateRequest
from .models.forward_plan_cancel_request import ForwardPlanCancelRequest
from .models.forward_plan_create_request import ForwardPlanCreateRequest
from .models.forward_plan_create_response import ForwardPlanCreateResponse
from .models.forward_plan_response import ForwardPlanResponse
from .models.forward_plan_status_response import ForwardPlanStatusResponse
from .models.forward_plan_summary_response import ForwardPlanSummaryResponse
from .models.forward_plan_update_request import ForwardPlanUpdateRequest
from .models.forward_plan_work_type import ForwardPlanWorkType
from .models.forward_plan_work_type_response import ForwardPlanWorkTypeResponse
from .models.geographical_area_create_response import GeographicalAreaCreateResponse
from .models.geographicalareas_body import GeographicalareasBody
from .models.geographicalareas_geographical_area_reference_number_body import GeographicalareasGeographicalAreaReferenceNumberBody
from .models.hs2_acknowledgement_request import HS2AcknowledgementRequest
from .models.hs2_highway_exemption import HS2HighwayExemption
from .models.hs2_highway_exemption_response import HS2HighwayExemptionResponse
from .models.hazardous_material_type import HazardousMaterialType
from .models.hazardous_material_type_response import HazardousMaterialTypeResponse
from .models.historic_fpn_create_request import HistoricFPNCreateRequest
from .models.historic_fpn_create_response import HistoricFPNCreateResponse
from .models.historic_failure_reason_details import HistoricFailureReasonDetails
from .models.historic_inspection_create_request import HistoricInspectionCreateRequest
from .models.historic_inspection_create_response import HistoricInspectionCreateResponse
from .models.impose_change_request import ImposeChangeRequest
from .models.impose_change_response import ImposeChangeResponse
from .models.industry_sector_response import IndustrySectorResponse
from .models.initial_authentication_response import InitialAuthenticationResponse
from .models.inspection_category import InspectionCategory
from .models.inspection_category_response import InspectionCategoryResponse
from .models.inspection_create_request import InspectionCreateRequest
from .models.inspection_create_response import InspectionCreateResponse
from .models.inspection_outcome import InspectionOutcome
from .models.inspection_outcome_response import InspectionOutcomeResponse
from .models.inspection_outcome_status_request import InspectionOutcomeStatusRequest
from .models.inspection_outcome_status_type import InspectionOutcomeStatusType
from .models.inspection_outcome_status_type_response import InspectionOutcomeStatusTypeResponse
from .models.inspection_reason_for_withdrawal import InspectionReasonForWithdrawal
from .models.inspection_reason_for_withdrawal_response import InspectionReasonForWithdrawalResponse
from .models.inspection_response import InspectionResponse
from .models.inspection_response_type_response import InspectionResponseTypeResponse
from .models.inspection_status_response import InspectionStatusResponse
from .models.inspection_summary_response import InspectionSummaryResponse
from .models.inspection_type import InspectionType
from .models.inspection_type_response import InspectionTypeResponse
from .models.inspection_withdraw_request import InspectionWithdrawRequest
from .models.interested_party import InterestedParty
from .models.jsm_status_response import JsmStatusResponse
from .models.lane_rental_assessment_charge_band import LaneRentalAssessmentChargeBand
from .models.lane_rental_assessment_charge_band_response import LaneRentalAssessmentChargeBandResponse
from .models.lane_rental_assessment_outcome import LaneRentalAssessmentOutcome
from .models.lane_rental_assessment_outcome_response import LaneRentalAssessmentOutcomeResponse
from .models.layer_affected import LayerAffected
from .models.layer_affected_response import LayerAffectedResponse
from .models.link_section81_to_permit_request import LinkSection81ToPermitRequest
from .models.link_section81_to_permit_response import LinkSection81ToPermitResponse
from .models.linked_permit import LinkedPermit
from .models.linked_section81 import LinkedSection81
from .models.location_type import LocationType
from .models.location_type_response import LocationTypeResponse
from .models.mark_permit_as_under_assessment_request import MarkPermitAsUnderAssessmentRequest
from .models.material_classification_classification import MaterialClassificationClassification
from .models.material_classification_classification_response import MaterialClassificationClassificationResponse
from .models.material_classification_create_request import MaterialClassificationCreateRequest
from .models.material_classification_create_response import MaterialClassificationCreateResponse
from .models.material_classification_response import MaterialClassificationResponse
from .models.non_compliance_response import NonComplianceResponse
from .models.non_compliance_response_status import NonComplianceResponseStatus
from .models.non_compliance_response_status_request import NonComplianceResponseStatusRequest
from .models.non_compliance_response_status_response import NonComplianceResponseStatusResponse
from .models.non_compliance_status_response import NonComplianceStatusResponse
from .models.non_compliance_summary_response import NonComplianceSummaryResponse
from .models.non_notifiable_site_create_request import NonNotifiableSiteCreateRequest
from .models.non_notifiable_site_create_response import NonNotifiableSiteCreateResponse
from .models.offence_code import OffenceCode
from .models.offence_code_response import OffenceCodeResponse
from .models.overrun_warning_reason import OverrunWarningReason
from .models.overrun_warning_reason_response import OverrunWarningReasonResponse
from .models.pagination_details import PaginationDetails
from .models.payment_method import PaymentMethod
from .models.payment_method_response import PaymentMethodResponse
from .models.pbi_sample_inspection_summary_response import PbiSampleInspectionSummaryResponse
from .models.permit_asd import PermitASD
from .models.permit_asd_response import PermitASDResponse
from .models.permit_alteration_create_request import PermitAlterationCreateRequest
from .models.permit_alteration_create_response import PermitAlterationCreateResponse
from .models.permit_alteration_duration_challenge_non_acceptance_response_request import PermitAlterationDurationChallengeNonAcceptanceResponseRequest
from .models.permit_alteration_duration_challenge_review_request import PermitAlterationDurationChallengeReviewRequest
from .models.permit_alteration_response import PermitAlterationResponse
from .models.permit_alteration_status_update_request import PermitAlterationStatusUpdateRequest
from .models.permit_alteration_summary_response import PermitAlterationSummaryResponse
from .models.permit_assessment_update_request import PermitAssessmentUpdateRequest
from .models.permit_cancellation_reason import PermitCancellationReason
from .models.permit_cancellation_reason_response import PermitCancellationReasonResponse
from .models.permit_condition import PermitCondition
from .models.permit_condition_response import PermitConditionResponse
from .models.permit_condition_type import PermitConditionType
from .models.permit_condition_type_response import PermitConditionTypeResponse
from .models.permit_create_request import PermitCreateRequest
from .models.permit_create_response import PermitCreateResponse
from .models.permit_discount_update_request import PermitDiscountUpdateRequest
from .models.permit_duration_challenge_non_acceptance_response_request import PermitDurationChallengeNonAcceptanceResponseRequest
from .models.permit_duration_challenge_review_request import PermitDurationChallengeReviewRequest
from .models.permit_lane_rental_assessment_update_request import PermitLaneRentalAssessmentUpdateRequest
from .models.permit_non_compliance_link_request import PermitNonComplianceLinkRequest
from .models.permit_response import PermitResponse
from .models.permit_status import PermitStatus
from .models.permit_status_response import PermitStatusResponse
from .models.permit_status_update_request import PermitStatusUpdateRequest
from .models.permit_summary_response import PermitSummaryResponse
from .models.private_street_notice_cancel_request import PrivateStreetNoticeCancelRequest
from .models.private_street_notice_create_request import PrivateStreetNoticeCreateRequest
from .models.private_street_notice_create_response import PrivateStreetNoticeCreateResponse
from .models.private_street_notice_response import PrivateStreetNoticeResponse
from .models.private_street_status_response import PrivateStreetStatusResponse
from .models.private_street_summary_response import PrivateStreetSummaryResponse
from .models.reason_for_refusal import ReasonForRefusal
from .models.reason_for_refusal_response import ReasonForRefusalResponse
from .models.reassign_section81_request import ReassignSection81Request
from .models.reinstatement_create_request import ReinstatementCreateRequest
from .models.reinstatement_create_response import ReinstatementCreateResponse
from .models.reinstatement_response import ReinstatementResponse
from .models.reinstatement_status import ReinstatementStatus
from .models.reinstatement_status_response import ReinstatementStatusResponse
from .models.reinstatement_type import ReinstatementType
from .models.reinstatement_type_response import ReinstatementTypeResponse
from .models.remove_ancillary_info_request import RemoveAncillaryInfoRequest
from .models.remove_ancillary_info_response import RemoveAncillaryInfoResponse
from .models.scheduled_inspection_create_request import ScheduledInspectionCreateRequest
from .models.section58_create_request import Section58CreateRequest
from .models.section58_create_response import Section58CreateResponse
from .models.section58_duration import Section58Duration
from .models.section58_duration_response import Section58DurationResponse
from .models.section58_extent import Section58Extent
from .models.section58_extent_response import Section58ExtentResponse
from .models.section58_response import Section58Response
from .models.section58_status import Section58Status
from .models.section58_status_response import Section58StatusResponse
from .models.section58_update_status_request import Section58UpdateStatusRequest
from .models.section74_create_request import Section74CreateRequest
from .models.section74_create_response import Section74CreateResponse
from .models.section74_ha_status import Section74HAStatus
from .models.section74_ha_status_response import Section74HAStatusResponse
from .models.section74_promoter_status import Section74PromoterStatus
from .models.section74_promoter_status_response import Section74PromoterStatusResponse
from .models.section74_response import Section74Response
from .models.section74_summary_response import Section74SummaryResponse
from .models.section74_update_ha_status_request import Section74UpdateHAStatusRequest
from .models.section74_update_promoter_status_request import Section74UpdatePromoterStatusRequest
from .models.section81_create_request import Section81CreateRequest
from .models.section81_create_response import Section81CreateResponse
from .models.section81_response import Section81Response
from .models.section81_severity import Section81Severity
from .models.section81_severity_response import Section81SeverityResponse
from .models.section81_status import Section81Status
from .models.section81_status_response import Section81StatusResponse
from .models.section81_status_update_request import Section81StatusUpdateRequest
from .models.section81_summary_response import Section81SummaryResponse
from .models.section81_type import Section81Type
from .models.section81_type_response import Section81TypeResponse
from .models.section81_work_type import Section81WorkType
from .models.section81_work_type_response import Section81WorkTypeResponse
from .models.site_create_request import SiteCreateRequest
from .models.site_create_response import SiteCreateResponse
from .models.site_details import SiteDetails
from .models.site_response import SiteResponse
from .models.site_summary_response import SiteSummaryResponse
from .models.subsume_site_request import SubsumeSiteRequest
from .models.traffic_management_type import TrafficManagementType
from .models.traffic_management_type_response import TrafficManagementTypeResponse
from .models.unlink_section81_from_permit_request import UnlinkSection81FromPermitRequest
from .models.work_category_response import WorkCategoryResponse
from .models.work_category_response_enum import WorkCategoryResponseEnum
from .models.work_create_request import WorkCreateRequest
from .models.work_create_response import WorkCreateResponse
from .models.work_history_response import WorkHistoryResponse
from .models.work_history_summary_response import WorkHistorySummaryResponse
from .models.work_response import WorkResponse
from .models.work_start_revert_request import WorkStartRevertRequest
from .models.work_start_update_request import WorkStartUpdateRequest
from .models.work_status_response import WorkStatusResponse
from .models.work_stop_revert_request import WorkStopRevertRequest
from .models.work_stop_update_request import WorkStopUpdateRequest
from .models.work_type import WorkType
from .models.work_type_response import WorkTypeResponse
