# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitDurationChallengeNonAcceptanceResponseRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'non_acceptance_response_status': 'DurationChallengeNonAcceptanceResponseStatus',
        'new_reasonable_period_end_date': 'datetime',
        'non_acceptance_response_details': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'non_acceptance_response_status': 'non_acceptance_response_status',
        'new_reasonable_period_end_date': 'new_reasonable_period_end_date',
        'non_acceptance_response_details': 'non_acceptance_response_details'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, non_acceptance_response_status=None, new_reasonable_period_end_date=None, non_acceptance_response_details=None):  # noqa: E501
        """PermitDurationChallengeNonAcceptanceResponseRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._non_acceptance_response_status = None
        self._new_reasonable_period_end_date = None
        self._non_acceptance_response_details = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.non_acceptance_response_status = non_acceptance_response_status
        if new_reasonable_period_end_date is not None:
            self.new_reasonable_period_end_date = new_reasonable_period_end_date
        self.non_acceptance_response_details = non_acceptance_response_details

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def non_acceptance_response_status(self):
        """Gets the non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501


        :return: The non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: DurationChallengeNonAcceptanceResponseStatus
        """
        return self._non_acceptance_response_status

    @non_acceptance_response_status.setter
    def non_acceptance_response_status(self, non_acceptance_response_status):
        """Sets the non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.


        :param non_acceptance_response_status: The non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: DurationChallengeNonAcceptanceResponseStatus
        """
        if non_acceptance_response_status is None:
            raise ValueError("Invalid value for `non_acceptance_response_status`, must not be `None`")  # noqa: E501

        self._non_acceptance_response_status = non_acceptance_response_status

    @property
    def new_reasonable_period_end_date(self):
        """Gets the new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Required if non_acceptance_response_status = reasonable_period_end_date_changed  # noqa: E501

        :return: The new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._new_reasonable_period_end_date

    @new_reasonable_period_end_date.setter
    def new_reasonable_period_end_date(self, new_reasonable_period_end_date):
        """Sets the new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Required if non_acceptance_response_status = reasonable_period_end_date_changed  # noqa: E501

        :param new_reasonable_period_end_date: The new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: datetime
        """

        self._new_reasonable_period_end_date = new_reasonable_period_end_date

    @property
    def non_acceptance_response_details(self):
        """Gets the non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: str
        """
        return self._non_acceptance_response_details

    @non_acceptance_response_details.setter
    def non_acceptance_response_details(self, non_acceptance_response_details):
        """Sets the non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Max length 500 characters  # noqa: E501

        :param non_acceptance_response_details: The non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: str
        """
        if non_acceptance_response_details is None:
            raise ValueError("Invalid value for `non_acceptance_response_details`, must not be `None`")  # noqa: E501

        self._non_acceptance_response_details = non_acceptance_response_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitDurationChallengeNonAcceptanceResponseRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitDurationChallengeNonAcceptanceResponseRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
