# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ForwardPlanResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'work_reference_number': 'str',
        'forward_plan_reference_number': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'forward_plan_status': 'ForwardPlanStatusResponse',
        'forward_plan_status_string': 'str',
        'promoter_organisation': 'str',
        'promoter_swa_code': 'str',
        'promoter_contact_details': 'str',
        'highway_authority': 'str',
        'highway_authority_swa_code': 'str',
        'workstream_prefix': 'str',
        'works_coordinates': 'object',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'float',
        'road_category': 'float',
        'date_created': 'datetime',
        'works_location_description': 'str',
        'description_of_work': 'str',
        'project_reference_number': 'str',
        'traffic_management_type': 'AllOfForwardPlanResponseTrafficManagementType',
        'traffic_management_type_string': 'str',
        'additional_info': 'str',
        'forward_plan_asds': 'list[PermitASDResponse]',
        'cancelled_reason': 'str',
        'hs2_in_act_limits': 'bool',
        'hs2_consultation_requested_response_date': 'datetime',
        'hs2_highway_exemption': 'AllOfForwardPlanResponseHs2HighwayExemption',
        'hs2_highway_exemption_string': 'str',
        'hs2_works_type': 'AllOfForwardPlanResponseHs2WorksType',
        'hs2_works_type_string': 'str'
    }

    attribute_map = {
        'work_reference_number': 'work_reference_number',
        'forward_plan_reference_number': 'forward_plan_reference_number',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'forward_plan_status': 'forward_plan_status',
        'forward_plan_status_string': 'forward_plan_status_string',
        'promoter_organisation': 'promoter_organisation',
        'promoter_swa_code': 'promoter_swa_code',
        'promoter_contact_details': 'promoter_contact_details',
        'highway_authority': 'highway_authority',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'workstream_prefix': 'workstream_prefix',
        'works_coordinates': 'works_coordinates',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'road_category': 'road_category',
        'date_created': 'date_created',
        'works_location_description': 'works_location_description',
        'description_of_work': 'description_of_work',
        'project_reference_number': 'project_reference_number',
        'traffic_management_type': 'traffic_management_type',
        'traffic_management_type_string': 'traffic_management_type_string',
        'additional_info': 'additional_info',
        'forward_plan_asds': 'forward_plan_asds',
        'cancelled_reason': 'cancelled_reason',
        'hs2_in_act_limits': 'hs2_in_act_limits',
        'hs2_consultation_requested_response_date': 'hs2_consultation_requested_response_date',
        'hs2_highway_exemption': 'hs2_highway_exemption',
        'hs2_highway_exemption_string': 'hs2_highway_exemption_string',
        'hs2_works_type': 'hs2_works_type',
        'hs2_works_type_string': 'hs2_works_type_string'
    }

    def __init__(self, work_reference_number=None, forward_plan_reference_number=None, start_date=None, end_date=None, forward_plan_status=None, forward_plan_status_string=None, promoter_organisation=None, promoter_swa_code=None, promoter_contact_details=None, highway_authority=None, highway_authority_swa_code=None, workstream_prefix=None, works_coordinates=None, street_name=None, town=None, area_name=None, usrn=None, road_category=None, date_created=None, works_location_description=None, description_of_work=None, project_reference_number=None, traffic_management_type=None, traffic_management_type_string=None, additional_info=None, forward_plan_asds=None, cancelled_reason=None, hs2_in_act_limits=None, hs2_consultation_requested_response_date=None, hs2_highway_exemption=None, hs2_highway_exemption_string=None, hs2_works_type=None, hs2_works_type_string=None):  # noqa: E501
        """ForwardPlanResponse - a model defined in Swagger"""  # noqa: E501
        self._work_reference_number = None
        self._forward_plan_reference_number = None
        self._start_date = None
        self._end_date = None
        self._forward_plan_status = None
        self._forward_plan_status_string = None
        self._promoter_organisation = None
        self._promoter_swa_code = None
        self._promoter_contact_details = None
        self._highway_authority = None
        self._highway_authority_swa_code = None
        self._workstream_prefix = None
        self._works_coordinates = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._road_category = None
        self._date_created = None
        self._works_location_description = None
        self._description_of_work = None
        self._project_reference_number = None
        self._traffic_management_type = None
        self._traffic_management_type_string = None
        self._additional_info = None
        self._forward_plan_asds = None
        self._cancelled_reason = None
        self._hs2_in_act_limits = None
        self._hs2_consultation_requested_response_date = None
        self._hs2_highway_exemption = None
        self._hs2_highway_exemption_string = None
        self._hs2_works_type = None
        self._hs2_works_type_string = None
        self.discriminator = None
        self.work_reference_number = work_reference_number
        self.forward_plan_reference_number = forward_plan_reference_number
        self.start_date = start_date
        self.end_date = end_date
        self.forward_plan_status = forward_plan_status
        self.forward_plan_status_string = forward_plan_status_string
        self.promoter_organisation = promoter_organisation
        self.promoter_swa_code = promoter_swa_code
        self.promoter_contact_details = promoter_contact_details
        self.highway_authority = highway_authority
        self.highway_authority_swa_code = highway_authority_swa_code
        self.workstream_prefix = workstream_prefix
        self.works_coordinates = works_coordinates
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        self.road_category = road_category
        self.date_created = date_created
        self.works_location_description = works_location_description
        self.description_of_work = description_of_work
        if project_reference_number is not None:
            self.project_reference_number = project_reference_number
        if traffic_management_type is not None:
            self.traffic_management_type = traffic_management_type
        if traffic_management_type_string is not None:
            self.traffic_management_type_string = traffic_management_type_string
        if additional_info is not None:
            self.additional_info = additional_info
        if forward_plan_asds is not None:
            self.forward_plan_asds = forward_plan_asds
        if cancelled_reason is not None:
            self.cancelled_reason = cancelled_reason
        if hs2_in_act_limits is not None:
            self.hs2_in_act_limits = hs2_in_act_limits
        if hs2_consultation_requested_response_date is not None:
            self.hs2_consultation_requested_response_date = hs2_consultation_requested_response_date
        if hs2_highway_exemption is not None:
            self.hs2_highway_exemption = hs2_highway_exemption
        if hs2_highway_exemption_string is not None:
            self.hs2_highway_exemption_string = hs2_highway_exemption_string
        if hs2_works_type is not None:
            self.hs2_works_type = hs2_works_type
        if hs2_works_type_string is not None:
            self.hs2_works_type_string = hs2_works_type_string

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this ForwardPlanResponse.  # noqa: E501


        :return: The work_reference_number of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this ForwardPlanResponse.


        :param work_reference_number: The work_reference_number of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def forward_plan_reference_number(self):
        """Gets the forward_plan_reference_number of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_reference_number of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._forward_plan_reference_number

    @forward_plan_reference_number.setter
    def forward_plan_reference_number(self, forward_plan_reference_number):
        """Sets the forward_plan_reference_number of this ForwardPlanResponse.


        :param forward_plan_reference_number: The forward_plan_reference_number of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if forward_plan_reference_number is None:
            raise ValueError("Invalid value for `forward_plan_reference_number`, must not be `None`")  # noqa: E501

        self._forward_plan_reference_number = forward_plan_reference_number

    @property
    def start_date(self):
        """Gets the start_date of this ForwardPlanResponse.  # noqa: E501


        :return: The start_date of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ForwardPlanResponse.


        :param start_date: The start_date of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ForwardPlanResponse.  # noqa: E501


        :return: The end_date of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ForwardPlanResponse.


        :param end_date: The end_date of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def forward_plan_status(self):
        """Gets the forward_plan_status of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_status of this ForwardPlanResponse.  # noqa: E501
        :rtype: ForwardPlanStatusResponse
        """
        return self._forward_plan_status

    @forward_plan_status.setter
    def forward_plan_status(self, forward_plan_status):
        """Sets the forward_plan_status of this ForwardPlanResponse.


        :param forward_plan_status: The forward_plan_status of this ForwardPlanResponse.  # noqa: E501
        :type: ForwardPlanStatusResponse
        """
        if forward_plan_status is None:
            raise ValueError("Invalid value for `forward_plan_status`, must not be `None`")  # noqa: E501

        self._forward_plan_status = forward_plan_status

    @property
    def forward_plan_status_string(self):
        """Gets the forward_plan_status_string of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_status_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._forward_plan_status_string

    @forward_plan_status_string.setter
    def forward_plan_status_string(self, forward_plan_status_string):
        """Sets the forward_plan_status_string of this ForwardPlanResponse.


        :param forward_plan_status_string: The forward_plan_status_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if forward_plan_status_string is None:
            raise ValueError("Invalid value for `forward_plan_status_string`, must not be `None`")  # noqa: E501

        self._forward_plan_status_string = forward_plan_status_string

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this ForwardPlanResponse.  # noqa: E501


        :return: The promoter_organisation of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this ForwardPlanResponse.


        :param promoter_organisation: The promoter_organisation of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this ForwardPlanResponse.  # noqa: E501


        :return: The promoter_swa_code of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this ForwardPlanResponse.


        :param promoter_swa_code: The promoter_swa_code of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def promoter_contact_details(self):
        """Gets the promoter_contact_details of this ForwardPlanResponse.  # noqa: E501


        :return: The promoter_contact_details of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_contact_details

    @promoter_contact_details.setter
    def promoter_contact_details(self, promoter_contact_details):
        """Sets the promoter_contact_details of this ForwardPlanResponse.


        :param promoter_contact_details: The promoter_contact_details of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if promoter_contact_details is None:
            raise ValueError("Invalid value for `promoter_contact_details`, must not be `None`")  # noqa: E501

        self._promoter_contact_details = promoter_contact_details

    @property
    def highway_authority(self):
        """Gets the highway_authority of this ForwardPlanResponse.  # noqa: E501


        :return: The highway_authority of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority

    @highway_authority.setter
    def highway_authority(self, highway_authority):
        """Sets the highway_authority of this ForwardPlanResponse.


        :param highway_authority: The highway_authority of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if highway_authority is None:
            raise ValueError("Invalid value for `highway_authority`, must not be `None`")  # noqa: E501

        self._highway_authority = highway_authority

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this ForwardPlanResponse.  # noqa: E501


        :return: The highway_authority_swa_code of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this ForwardPlanResponse.


        :param highway_authority_swa_code: The highway_authority_swa_code of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def workstream_prefix(self):
        """Gets the workstream_prefix of this ForwardPlanResponse.  # noqa: E501


        :return: The workstream_prefix of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._workstream_prefix

    @workstream_prefix.setter
    def workstream_prefix(self, workstream_prefix):
        """Sets the workstream_prefix of this ForwardPlanResponse.


        :param workstream_prefix: The workstream_prefix of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if workstream_prefix is None:
            raise ValueError("Invalid value for `workstream_prefix`, must not be `None`")  # noqa: E501

        self._workstream_prefix = workstream_prefix

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this ForwardPlanResponse.  # noqa: E501


        :return: The works_coordinates of this ForwardPlanResponse.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this ForwardPlanResponse.


        :param works_coordinates: The works_coordinates of this ForwardPlanResponse.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def street_name(self):
        """Gets the street_name of this ForwardPlanResponse.  # noqa: E501


        :return: The street_name of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this ForwardPlanResponse.


        :param street_name: The street_name of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this ForwardPlanResponse.  # noqa: E501


        :return: The town of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this ForwardPlanResponse.


        :param town: The town of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this ForwardPlanResponse.  # noqa: E501


        :return: The area_name of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this ForwardPlanResponse.


        :param area_name: The area_name of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this ForwardPlanResponse.  # noqa: E501


        :return: The usrn of this ForwardPlanResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this ForwardPlanResponse.


        :param usrn: The usrn of this ForwardPlanResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def road_category(self):
        """Gets the road_category of this ForwardPlanResponse.  # noqa: E501


        :return: The road_category of this ForwardPlanResponse.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this ForwardPlanResponse.


        :param road_category: The road_category of this ForwardPlanResponse.  # noqa: E501
        :type: float
        """
        if road_category is None:
            raise ValueError("Invalid value for `road_category`, must not be `None`")  # noqa: E501

        self._road_category = road_category

    @property
    def date_created(self):
        """Gets the date_created of this ForwardPlanResponse.  # noqa: E501


        :return: The date_created of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ForwardPlanResponse.


        :param date_created: The date_created of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def works_location_description(self):
        """Gets the works_location_description of this ForwardPlanResponse.  # noqa: E501


        :return: The works_location_description of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this ForwardPlanResponse.


        :param works_location_description: The works_location_description of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def description_of_work(self):
        """Gets the description_of_work of this ForwardPlanResponse.  # noqa: E501


        :return: The description_of_work of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this ForwardPlanResponse.


        :param description_of_work: The description_of_work of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if description_of_work is None:
            raise ValueError("Invalid value for `description_of_work`, must not be `None`")  # noqa: E501

        self._description_of_work = description_of_work

    @property
    def project_reference_number(self):
        """Gets the project_reference_number of this ForwardPlanResponse.  # noqa: E501


        :return: The project_reference_number of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_reference_number

    @project_reference_number.setter
    def project_reference_number(self, project_reference_number):
        """Sets the project_reference_number of this ForwardPlanResponse.


        :param project_reference_number: The project_reference_number of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._project_reference_number = project_reference_number

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this ForwardPlanResponse.  # noqa: E501


        :return: The traffic_management_type of this ForwardPlanResponse.  # noqa: E501
        :rtype: AllOfForwardPlanResponseTrafficManagementType
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this ForwardPlanResponse.


        :param traffic_management_type: The traffic_management_type of this ForwardPlanResponse.  # noqa: E501
        :type: AllOfForwardPlanResponseTrafficManagementType
        """

        self._traffic_management_type = traffic_management_type

    @property
    def traffic_management_type_string(self):
        """Gets the traffic_management_type_string of this ForwardPlanResponse.  # noqa: E501


        :return: The traffic_management_type_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._traffic_management_type_string

    @traffic_management_type_string.setter
    def traffic_management_type_string(self, traffic_management_type_string):
        """Sets the traffic_management_type_string of this ForwardPlanResponse.


        :param traffic_management_type_string: The traffic_management_type_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._traffic_management_type_string = traffic_management_type_string

    @property
    def additional_info(self):
        """Gets the additional_info of this ForwardPlanResponse.  # noqa: E501


        :return: The additional_info of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this ForwardPlanResponse.


        :param additional_info: The additional_info of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def forward_plan_asds(self):
        """Gets the forward_plan_asds of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_asds of this ForwardPlanResponse.  # noqa: E501
        :rtype: list[PermitASDResponse]
        """
        return self._forward_plan_asds

    @forward_plan_asds.setter
    def forward_plan_asds(self, forward_plan_asds):
        """Sets the forward_plan_asds of this ForwardPlanResponse.


        :param forward_plan_asds: The forward_plan_asds of this ForwardPlanResponse.  # noqa: E501
        :type: list[PermitASDResponse]
        """

        self._forward_plan_asds = forward_plan_asds

    @property
    def cancelled_reason(self):
        """Gets the cancelled_reason of this ForwardPlanResponse.  # noqa: E501


        :return: The cancelled_reason of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._cancelled_reason

    @cancelled_reason.setter
    def cancelled_reason(self, cancelled_reason):
        """Sets the cancelled_reason of this ForwardPlanResponse.


        :param cancelled_reason: The cancelled_reason of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._cancelled_reason = cancelled_reason

    @property
    def hs2_in_act_limits(self):
        """Gets the hs2_in_act_limits of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_in_act_limits of this ForwardPlanResponse.  # noqa: E501
        :rtype: bool
        """
        return self._hs2_in_act_limits

    @hs2_in_act_limits.setter
    def hs2_in_act_limits(self, hs2_in_act_limits):
        """Sets the hs2_in_act_limits of this ForwardPlanResponse.


        :param hs2_in_act_limits: The hs2_in_act_limits of this ForwardPlanResponse.  # noqa: E501
        :type: bool
        """

        self._hs2_in_act_limits = hs2_in_act_limits

    @property
    def hs2_consultation_requested_response_date(self):
        """Gets the hs2_consultation_requested_response_date of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_consultation_requested_response_date of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._hs2_consultation_requested_response_date

    @hs2_consultation_requested_response_date.setter
    def hs2_consultation_requested_response_date(self, hs2_consultation_requested_response_date):
        """Sets the hs2_consultation_requested_response_date of this ForwardPlanResponse.


        :param hs2_consultation_requested_response_date: The hs2_consultation_requested_response_date of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """

        self._hs2_consultation_requested_response_date = hs2_consultation_requested_response_date

    @property
    def hs2_highway_exemption(self):
        """Gets the hs2_highway_exemption of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_highway_exemption of this ForwardPlanResponse.  # noqa: E501
        :rtype: AllOfForwardPlanResponseHs2HighwayExemption
        """
        return self._hs2_highway_exemption

    @hs2_highway_exemption.setter
    def hs2_highway_exemption(self, hs2_highway_exemption):
        """Sets the hs2_highway_exemption of this ForwardPlanResponse.


        :param hs2_highway_exemption: The hs2_highway_exemption of this ForwardPlanResponse.  # noqa: E501
        :type: AllOfForwardPlanResponseHs2HighwayExemption
        """

        self._hs2_highway_exemption = hs2_highway_exemption

    @property
    def hs2_highway_exemption_string(self):
        """Gets the hs2_highway_exemption_string of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_highway_exemption_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._hs2_highway_exemption_string

    @hs2_highway_exemption_string.setter
    def hs2_highway_exemption_string(self, hs2_highway_exemption_string):
        """Sets the hs2_highway_exemption_string of this ForwardPlanResponse.


        :param hs2_highway_exemption_string: The hs2_highway_exemption_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._hs2_highway_exemption_string = hs2_highway_exemption_string

    @property
    def hs2_works_type(self):
        """Gets the hs2_works_type of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_works_type of this ForwardPlanResponse.  # noqa: E501
        :rtype: AllOfForwardPlanResponseHs2WorksType
        """
        return self._hs2_works_type

    @hs2_works_type.setter
    def hs2_works_type(self, hs2_works_type):
        """Sets the hs2_works_type of this ForwardPlanResponse.


        :param hs2_works_type: The hs2_works_type of this ForwardPlanResponse.  # noqa: E501
        :type: AllOfForwardPlanResponseHs2WorksType
        """

        self._hs2_works_type = hs2_works_type

    @property
    def hs2_works_type_string(self):
        """Gets the hs2_works_type_string of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_works_type_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._hs2_works_type_string

    @hs2_works_type_string.setter
    def hs2_works_type_string(self, hs2_works_type_string):
        """Sets the hs2_works_type_string of this ForwardPlanResponse.


        :param hs2_works_type_string: The hs2_works_type_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._hs2_works_type_string = hs2_works_type_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForwardPlanResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForwardPlanResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
