# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.default_api import DefaultApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_activities_intersecting_bounds(self):
        """Test case for get_activities_intersecting_bounds

        """
        pass

    def test_get_ancillary_information_intersect_bounding_box(self):
        """Test case for get_ancillary_information_intersect_bounding_box

        """
        pass

    def test_get_forward_plans_intersect_bounding_box(self):
        """Test case for get_forward_plans_intersect_bounding_box

        """
        pass

    def test_get_hs2_act_limits_intersecting_bounds(self):
        """Test case for get_hs2_act_limits_intersecting_bounds

        """
        pass

    def test_get_material_classifications_intersect_bounding_box(self):
        """Test case for get_material_classifications_intersect_bounding_box

        """
        pass

    def test_get_section58s_intersect_bounding_box(self):
        """Test case for get_section58s_intersect_bounding_box

        """
        pass

    def test_get_works_intersect_bounding_box(self):
        """Test case for get_works_intersect_bounding_box

        """
        pass


if __name__ == '__main__':
    unittest.main()
