# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkHistoryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pagination': 'PaginationDetails',
        'rows': 'list[WorkHistorySummaryResponse]'
    }

    attribute_map = {
        'pagination': 'pagination',
        'rows': 'rows'
    }

    def __init__(self, pagination=None, rows=None):  # noqa: E501
        """WorkHistoryResponse - a model defined in Swagger"""  # noqa: E501
        self._pagination = None
        self._rows = None
        self.discriminator = None
        self.pagination = pagination
        self.rows = rows

    @property
    def pagination(self):
        """Gets the pagination of this WorkHistoryResponse.  # noqa: E501


        :return: The pagination of this WorkHistoryResponse.  # noqa: E501
        :rtype: PaginationDetails
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this WorkHistoryResponse.


        :param pagination: The pagination of this WorkHistoryResponse.  # noqa: E501
        :type: PaginationDetails
        """
        if pagination is None:
            raise ValueError("Invalid value for `pagination`, must not be `None`")  # noqa: E501

        self._pagination = pagination

    @property
    def rows(self):
        """Gets the rows of this WorkHistoryResponse.  # noqa: E501


        :return: The rows of this WorkHistoryResponse.  # noqa: E501
        :rtype: list[WorkHistorySummaryResponse]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """Sets the rows of this WorkHistoryResponse.


        :param rows: The rows of this WorkHistoryResponse.  # noqa: E501
        :type: list[WorkHistorySummaryResponse]
        """
        if rows is None:
            raise ValueError("Invalid value for `rows`, must not be `None`")  # noqa: E501

        self._rows = rows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkHistoryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkHistoryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
