# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CommentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment_reference_number': 'str',
        'comment_topic': 'CommentTopicResponse',
        'comment_topic_string': 'str',
        'detail': 'str',
        'author_email_address': 'str',
        'date_created': 'datetime',
        'is_read': 'bool',
        'read_by': 'str',
        'read_on': 'datetime',
        'is_internal': 'bool',
        'author_organisation_ref': 'str'
    }

    attribute_map = {
        'comment_reference_number': 'comment_reference_number',
        'comment_topic': 'comment_topic',
        'comment_topic_string': 'comment_topic_string',
        'detail': 'detail',
        'author_email_address': 'author_email_address',
        'date_created': 'date_created',
        'is_read': 'is_read',
        'read_by': 'read_by',
        'read_on': 'read_on',
        'is_internal': 'is_internal',
        'author_organisation_ref': 'author_organisation_ref'
    }

    def __init__(self, comment_reference_number=None, comment_topic=None, comment_topic_string=None, detail=None, author_email_address=None, date_created=None, is_read=None, read_by=None, read_on=None, is_internal=None, author_organisation_ref=None):  # noqa: E501
        """CommentResponse - a model defined in Swagger"""  # noqa: E501
        self._comment_reference_number = None
        self._comment_topic = None
        self._comment_topic_string = None
        self._detail = None
        self._author_email_address = None
        self._date_created = None
        self._is_read = None
        self._read_by = None
        self._read_on = None
        self._is_internal = None
        self._author_organisation_ref = None
        self.discriminator = None
        if comment_reference_number is not None:
            self.comment_reference_number = comment_reference_number
        self.comment_topic = comment_topic
        self.comment_topic_string = comment_topic_string
        self.detail = detail
        self.author_email_address = author_email_address
        self.date_created = date_created
        if is_read is not None:
            self.is_read = is_read
        if read_by is not None:
            self.read_by = read_by
        if read_on is not None:
            self.read_on = read_on
        if is_internal is not None:
            self.is_internal = is_internal
        if author_organisation_ref is not None:
            self.author_organisation_ref = author_organisation_ref

    @property
    def comment_reference_number(self):
        """Gets the comment_reference_number of this CommentResponse.  # noqa: E501


        :return: The comment_reference_number of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._comment_reference_number

    @comment_reference_number.setter
    def comment_reference_number(self, comment_reference_number):
        """Sets the comment_reference_number of this CommentResponse.


        :param comment_reference_number: The comment_reference_number of this CommentResponse.  # noqa: E501
        :type: str
        """

        self._comment_reference_number = comment_reference_number

    @property
    def comment_topic(self):
        """Gets the comment_topic of this CommentResponse.  # noqa: E501


        :return: The comment_topic of this CommentResponse.  # noqa: E501
        :rtype: CommentTopicResponse
        """
        return self._comment_topic

    @comment_topic.setter
    def comment_topic(self, comment_topic):
        """Sets the comment_topic of this CommentResponse.


        :param comment_topic: The comment_topic of this CommentResponse.  # noqa: E501
        :type: CommentTopicResponse
        """
        if comment_topic is None:
            raise ValueError("Invalid value for `comment_topic`, must not be `None`")  # noqa: E501

        self._comment_topic = comment_topic

    @property
    def comment_topic_string(self):
        """Gets the comment_topic_string of this CommentResponse.  # noqa: E501


        :return: The comment_topic_string of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._comment_topic_string

    @comment_topic_string.setter
    def comment_topic_string(self, comment_topic_string):
        """Sets the comment_topic_string of this CommentResponse.


        :param comment_topic_string: The comment_topic_string of this CommentResponse.  # noqa: E501
        :type: str
        """
        if comment_topic_string is None:
            raise ValueError("Invalid value for `comment_topic_string`, must not be `None`")  # noqa: E501

        self._comment_topic_string = comment_topic_string

    @property
    def detail(self):
        """Gets the detail of this CommentResponse.  # noqa: E501


        :return: The detail of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this CommentResponse.


        :param detail: The detail of this CommentResponse.  # noqa: E501
        :type: str
        """
        if detail is None:
            raise ValueError("Invalid value for `detail`, must not be `None`")  # noqa: E501

        self._detail = detail

    @property
    def author_email_address(self):
        """Gets the author_email_address of this CommentResponse.  # noqa: E501


        :return: The author_email_address of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._author_email_address

    @author_email_address.setter
    def author_email_address(self, author_email_address):
        """Sets the author_email_address of this CommentResponse.


        :param author_email_address: The author_email_address of this CommentResponse.  # noqa: E501
        :type: str
        """
        if author_email_address is None:
            raise ValueError("Invalid value for `author_email_address`, must not be `None`")  # noqa: E501

        self._author_email_address = author_email_address

    @property
    def date_created(self):
        """Gets the date_created of this CommentResponse.  # noqa: E501


        :return: The date_created of this CommentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this CommentResponse.


        :param date_created: The date_created of this CommentResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def is_read(self):
        """Gets the is_read of this CommentResponse.  # noqa: E501


        :return: The is_read of this CommentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_read

    @is_read.setter
    def is_read(self, is_read):
        """Sets the is_read of this CommentResponse.


        :param is_read: The is_read of this CommentResponse.  # noqa: E501
        :type: bool
        """

        self._is_read = is_read

    @property
    def read_by(self):
        """Gets the read_by of this CommentResponse.  # noqa: E501


        :return: The read_by of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._read_by

    @read_by.setter
    def read_by(self, read_by):
        """Sets the read_by of this CommentResponse.


        :param read_by: The read_by of this CommentResponse.  # noqa: E501
        :type: str
        """

        self._read_by = read_by

    @property
    def read_on(self):
        """Gets the read_on of this CommentResponse.  # noqa: E501


        :return: The read_on of this CommentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._read_on

    @read_on.setter
    def read_on(self, read_on):
        """Sets the read_on of this CommentResponse.


        :param read_on: The read_on of this CommentResponse.  # noqa: E501
        :type: datetime
        """

        self._read_on = read_on

    @property
    def is_internal(self):
        """Gets the is_internal of this CommentResponse.  # noqa: E501


        :return: The is_internal of this CommentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_internal

    @is_internal.setter
    def is_internal(self, is_internal):
        """Sets the is_internal of this CommentResponse.


        :param is_internal: The is_internal of this CommentResponse.  # noqa: E501
        :type: bool
        """

        self._is_internal = is_internal

    @property
    def author_organisation_ref(self):
        """Gets the author_organisation_ref of this CommentResponse.  # noqa: E501


        :return: The author_organisation_ref of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._author_organisation_ref

    @author_organisation_ref.setter
    def author_organisation_ref(self, author_organisation_ref):
        """Sets the author_organisation_ref of this CommentResponse.


        :param author_organisation_ref: The author_organisation_ref of this CommentResponse.  # noqa: E501
        :type: str
        """

        self._author_organisation_ref = author_organisation_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CommentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
