# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DurationCalculationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'calendar_days': 'float',
        'working_days': 'float'
    }

    attribute_map = {
        'calendar_days': 'calendar_days',
        'working_days': 'working_days'
    }

    def __init__(self, calendar_days=None, working_days=None):  # noqa: E501
        """DurationCalculationResponse - a model defined in Swagger"""  # noqa: E501
        self._calendar_days = None
        self._working_days = None
        self.discriminator = None
        self.calendar_days = calendar_days
        self.working_days = working_days

    @property
    def calendar_days(self):
        """Gets the calendar_days of this DurationCalculationResponse.  # noqa: E501


        :return: The calendar_days of this DurationCalculationResponse.  # noqa: E501
        :rtype: float
        """
        return self._calendar_days

    @calendar_days.setter
    def calendar_days(self, calendar_days):
        """Sets the calendar_days of this DurationCalculationResponse.


        :param calendar_days: The calendar_days of this DurationCalculationResponse.  # noqa: E501
        :type: float
        """
        if calendar_days is None:
            raise ValueError("Invalid value for `calendar_days`, must not be `None`")  # noqa: E501

        self._calendar_days = calendar_days

    @property
    def working_days(self):
        """Gets the working_days of this DurationCalculationResponse.  # noqa: E501


        :return: The working_days of this DurationCalculationResponse.  # noqa: E501
        :rtype: float
        """
        return self._working_days

    @working_days.setter
    def working_days(self, working_days):
        """Sets the working_days of this DurationCalculationResponse.


        :param working_days: The working_days of this DurationCalculationResponse.  # noqa: E501
        :type: float
        """
        if working_days is None:
            raise ValueError("Invalid value for `working_days`, must not be `None`")  # noqa: E501

        self._working_days = working_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DurationCalculationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DurationCalculationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
