# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InspectionSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'inspection_date': 'datetime',
        'inspection_response_type': 'InspectionResponseTypeResponse',
        'inspection_response_type_string': 'str',
        'inspection_reference_number': 'str',
        'inspection_type': 'InspectionTypeResponse',
        'inspection_type_string': 'str',
        'inspection_status': 'InspectionStatusResponse',
        'inspection_status_string': 'str',
        'inspection_category': 'AllOfInspectionSummaryResponseInspectionCategory',
        'inspection_category_string': 'str',
        'inspection_outcome': 'AllOfInspectionSummaryResponseInspectionOutcome',
        'inspection_outcome_string': 'str',
        'reinspection_date_time': 'datetime',
        'auto_acceptance_due_date': 'datetime',
        'ha_response_status': 'InspectionOutcomeStatusTypeResponse',
        'ha_response_status_string': 'str',
        'ha_response_status_change_date': 'datetime',
        'ha_response_details': 'str',
        'promoter_response_status': 'InspectionOutcomeStatusTypeResponse',
        'promoter_response_status_string': 'str',
        'promoter_response_status_change_date': 'datetime',
        'promoter_response_details': 'str',
        'is_auto_accepted': 'bool',
        'non_compliance_reference_number': 'str'
    }

    attribute_map = {
        'inspection_date': 'inspection_date',
        'inspection_response_type': 'inspection_response_type',
        'inspection_response_type_string': 'inspection_response_type_string',
        'inspection_reference_number': 'inspection_reference_number',
        'inspection_type': 'inspection_type',
        'inspection_type_string': 'inspection_type_string',
        'inspection_status': 'inspection_status',
        'inspection_status_string': 'inspection_status_string',
        'inspection_category': 'inspection_category',
        'inspection_category_string': 'inspection_category_string',
        'inspection_outcome': 'inspection_outcome',
        'inspection_outcome_string': 'inspection_outcome_string',
        'reinspection_date_time': 'reinspection_date_time',
        'auto_acceptance_due_date': 'auto_acceptance_due_date',
        'ha_response_status': 'ha_response_status',
        'ha_response_status_string': 'ha_response_status_string',
        'ha_response_status_change_date': 'ha_response_status_change_date',
        'ha_response_details': 'ha_response_details',
        'promoter_response_status': 'promoter_response_status',
        'promoter_response_status_string': 'promoter_response_status_string',
        'promoter_response_status_change_date': 'promoter_response_status_change_date',
        'promoter_response_details': 'promoter_response_details',
        'is_auto_accepted': 'is_auto_accepted',
        'non_compliance_reference_number': 'non_compliance_reference_number'
    }

    def __init__(self, inspection_date=None, inspection_response_type=None, inspection_response_type_string=None, inspection_reference_number=None, inspection_type=None, inspection_type_string=None, inspection_status=None, inspection_status_string=None, inspection_category=None, inspection_category_string=None, inspection_outcome=None, inspection_outcome_string=None, reinspection_date_time=None, auto_acceptance_due_date=None, ha_response_status=None, ha_response_status_string=None, ha_response_status_change_date=None, ha_response_details=None, promoter_response_status=None, promoter_response_status_string=None, promoter_response_status_change_date=None, promoter_response_details=None, is_auto_accepted=None, non_compliance_reference_number=None):  # noqa: E501
        """InspectionSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._inspection_date = None
        self._inspection_response_type = None
        self._inspection_response_type_string = None
        self._inspection_reference_number = None
        self._inspection_type = None
        self._inspection_type_string = None
        self._inspection_status = None
        self._inspection_status_string = None
        self._inspection_category = None
        self._inspection_category_string = None
        self._inspection_outcome = None
        self._inspection_outcome_string = None
        self._reinspection_date_time = None
        self._auto_acceptance_due_date = None
        self._ha_response_status = None
        self._ha_response_status_string = None
        self._ha_response_status_change_date = None
        self._ha_response_details = None
        self._promoter_response_status = None
        self._promoter_response_status_string = None
        self._promoter_response_status_change_date = None
        self._promoter_response_details = None
        self._is_auto_accepted = None
        self._non_compliance_reference_number = None
        self.discriminator = None
        self.inspection_date = inspection_date
        self.inspection_response_type = inspection_response_type
        self.inspection_response_type_string = inspection_response_type_string
        if inspection_reference_number is not None:
            self.inspection_reference_number = inspection_reference_number
        self.inspection_type = inspection_type
        self.inspection_type_string = inspection_type_string
        self.inspection_status = inspection_status
        self.inspection_status_string = inspection_status_string
        if inspection_category is not None:
            self.inspection_category = inspection_category
        if inspection_category_string is not None:
            self.inspection_category_string = inspection_category_string
        if inspection_outcome is not None:
            self.inspection_outcome = inspection_outcome
        if inspection_outcome_string is not None:
            self.inspection_outcome_string = inspection_outcome_string
        if reinspection_date_time is not None:
            self.reinspection_date_time = reinspection_date_time
        if auto_acceptance_due_date is not None:
            self.auto_acceptance_due_date = auto_acceptance_due_date
        if ha_response_status is not None:
            self.ha_response_status = ha_response_status
        if ha_response_status_string is not None:
            self.ha_response_status_string = ha_response_status_string
        if ha_response_status_change_date is not None:
            self.ha_response_status_change_date = ha_response_status_change_date
        if ha_response_details is not None:
            self.ha_response_details = ha_response_details
        if promoter_response_status is not None:
            self.promoter_response_status = promoter_response_status
        if promoter_response_status_string is not None:
            self.promoter_response_status_string = promoter_response_status_string
        if promoter_response_status_change_date is not None:
            self.promoter_response_status_change_date = promoter_response_status_change_date
        if promoter_response_details is not None:
            self.promoter_response_details = promoter_response_details
        if is_auto_accepted is not None:
            self.is_auto_accepted = is_auto_accepted
        if non_compliance_reference_number is not None:
            self.non_compliance_reference_number = non_compliance_reference_number

    @property
    def inspection_date(self):
        """Gets the inspection_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_date

    @inspection_date.setter
    def inspection_date(self, inspection_date):
        """Sets the inspection_date of this InspectionSummaryResponse.


        :param inspection_date: The inspection_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if inspection_date is None:
            raise ValueError("Invalid value for `inspection_date`, must not be `None`")  # noqa: E501

        self._inspection_date = inspection_date

    @property
    def inspection_response_type(self):
        """Gets the inspection_response_type of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_response_type of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionResponseTypeResponse
        """
        return self._inspection_response_type

    @inspection_response_type.setter
    def inspection_response_type(self, inspection_response_type):
        """Sets the inspection_response_type of this InspectionSummaryResponse.


        :param inspection_response_type: The inspection_response_type of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionResponseTypeResponse
        """
        if inspection_response_type is None:
            raise ValueError("Invalid value for `inspection_response_type`, must not be `None`")  # noqa: E501

        self._inspection_response_type = inspection_response_type

    @property
    def inspection_response_type_string(self):
        """Gets the inspection_response_type_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_response_type_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_response_type_string

    @inspection_response_type_string.setter
    def inspection_response_type_string(self, inspection_response_type_string):
        """Sets the inspection_response_type_string of this InspectionSummaryResponse.


        :param inspection_response_type_string: The inspection_response_type_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_response_type_string is None:
            raise ValueError("Invalid value for `inspection_response_type_string`, must not be `None`")  # noqa: E501

        self._inspection_response_type_string = inspection_response_type_string

    @property
    def inspection_reference_number(self):
        """Gets the inspection_reference_number of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_reference_number

    @inspection_reference_number.setter
    def inspection_reference_number(self, inspection_reference_number):
        """Sets the inspection_reference_number of this InspectionSummaryResponse.


        :param inspection_reference_number: The inspection_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._inspection_reference_number = inspection_reference_number

    @property
    def inspection_type(self):
        """Gets the inspection_type of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_type of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionTypeResponse
        """
        return self._inspection_type

    @inspection_type.setter
    def inspection_type(self, inspection_type):
        """Sets the inspection_type of this InspectionSummaryResponse.


        :param inspection_type: The inspection_type of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionTypeResponse
        """
        if inspection_type is None:
            raise ValueError("Invalid value for `inspection_type`, must not be `None`")  # noqa: E501

        self._inspection_type = inspection_type

    @property
    def inspection_type_string(self):
        """Gets the inspection_type_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_type_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_type_string

    @inspection_type_string.setter
    def inspection_type_string(self, inspection_type_string):
        """Sets the inspection_type_string of this InspectionSummaryResponse.


        :param inspection_type_string: The inspection_type_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_type_string is None:
            raise ValueError("Invalid value for `inspection_type_string`, must not be `None`")  # noqa: E501

        self._inspection_type_string = inspection_type_string

    @property
    def inspection_status(self):
        """Gets the inspection_status of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_status of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionStatusResponse
        """
        return self._inspection_status

    @inspection_status.setter
    def inspection_status(self, inspection_status):
        """Sets the inspection_status of this InspectionSummaryResponse.


        :param inspection_status: The inspection_status of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionStatusResponse
        """
        if inspection_status is None:
            raise ValueError("Invalid value for `inspection_status`, must not be `None`")  # noqa: E501

        self._inspection_status = inspection_status

    @property
    def inspection_status_string(self):
        """Gets the inspection_status_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_status_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_status_string

    @inspection_status_string.setter
    def inspection_status_string(self, inspection_status_string):
        """Sets the inspection_status_string of this InspectionSummaryResponse.


        :param inspection_status_string: The inspection_status_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_status_string is None:
            raise ValueError("Invalid value for `inspection_status_string`, must not be `None`")  # noqa: E501

        self._inspection_status_string = inspection_status_string

    @property
    def inspection_category(self):
        """Gets the inspection_category of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_category of this InspectionSummaryResponse.  # noqa: E501
        :rtype: AllOfInspectionSummaryResponseInspectionCategory
        """
        return self._inspection_category

    @inspection_category.setter
    def inspection_category(self, inspection_category):
        """Sets the inspection_category of this InspectionSummaryResponse.


        :param inspection_category: The inspection_category of this InspectionSummaryResponse.  # noqa: E501
        :type: AllOfInspectionSummaryResponseInspectionCategory
        """

        self._inspection_category = inspection_category

    @property
    def inspection_category_string(self):
        """Gets the inspection_category_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_category_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_category_string

    @inspection_category_string.setter
    def inspection_category_string(self, inspection_category_string):
        """Sets the inspection_category_string of this InspectionSummaryResponse.


        :param inspection_category_string: The inspection_category_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._inspection_category_string = inspection_category_string

    @property
    def inspection_outcome(self):
        """Gets the inspection_outcome of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_outcome of this InspectionSummaryResponse.  # noqa: E501
        :rtype: AllOfInspectionSummaryResponseInspectionOutcome
        """
        return self._inspection_outcome

    @inspection_outcome.setter
    def inspection_outcome(self, inspection_outcome):
        """Sets the inspection_outcome of this InspectionSummaryResponse.


        :param inspection_outcome: The inspection_outcome of this InspectionSummaryResponse.  # noqa: E501
        :type: AllOfInspectionSummaryResponseInspectionOutcome
        """

        self._inspection_outcome = inspection_outcome

    @property
    def inspection_outcome_string(self):
        """Gets the inspection_outcome_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_outcome_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_outcome_string

    @inspection_outcome_string.setter
    def inspection_outcome_string(self, inspection_outcome_string):
        """Sets the inspection_outcome_string of this InspectionSummaryResponse.


        :param inspection_outcome_string: The inspection_outcome_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._inspection_outcome_string = inspection_outcome_string

    @property
    def reinspection_date_time(self):
        """Gets the reinspection_date_time of this InspectionSummaryResponse.  # noqa: E501


        :return: The reinspection_date_time of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date_time

    @reinspection_date_time.setter
    def reinspection_date_time(self, reinspection_date_time):
        """Sets the reinspection_date_time of this InspectionSummaryResponse.


        :param reinspection_date_time: The reinspection_date_time of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date_time = reinspection_date_time

    @property
    def auto_acceptance_due_date(self):
        """Gets the auto_acceptance_due_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The auto_acceptance_due_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._auto_acceptance_due_date

    @auto_acceptance_due_date.setter
    def auto_acceptance_due_date(self, auto_acceptance_due_date):
        """Sets the auto_acceptance_due_date of this InspectionSummaryResponse.


        :param auto_acceptance_due_date: The auto_acceptance_due_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._auto_acceptance_due_date = auto_acceptance_due_date

    @property
    def ha_response_status(self):
        """Gets the ha_response_status of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_status of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionOutcomeStatusTypeResponse
        """
        return self._ha_response_status

    @ha_response_status.setter
    def ha_response_status(self, ha_response_status):
        """Sets the ha_response_status of this InspectionSummaryResponse.


        :param ha_response_status: The ha_response_status of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionOutcomeStatusTypeResponse
        """

        self._ha_response_status = ha_response_status

    @property
    def ha_response_status_string(self):
        """Gets the ha_response_status_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_response_status_string

    @ha_response_status_string.setter
    def ha_response_status_string(self, ha_response_status_string):
        """Sets the ha_response_status_string of this InspectionSummaryResponse.


        :param ha_response_status_string: The ha_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._ha_response_status_string = ha_response_status_string

    @property
    def ha_response_status_change_date(self):
        """Gets the ha_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._ha_response_status_change_date

    @ha_response_status_change_date.setter
    def ha_response_status_change_date(self, ha_response_status_change_date):
        """Sets the ha_response_status_change_date of this InspectionSummaryResponse.


        :param ha_response_status_change_date: The ha_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._ha_response_status_change_date = ha_response_status_change_date

    @property
    def ha_response_details(self):
        """Gets the ha_response_details of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_details of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_response_details

    @ha_response_details.setter
    def ha_response_details(self, ha_response_details):
        """Sets the ha_response_details of this InspectionSummaryResponse.


        :param ha_response_details: The ha_response_details of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._ha_response_details = ha_response_details

    @property
    def promoter_response_status(self):
        """Gets the promoter_response_status of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_status of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionOutcomeStatusTypeResponse
        """
        return self._promoter_response_status

    @promoter_response_status.setter
    def promoter_response_status(self, promoter_response_status):
        """Sets the promoter_response_status of this InspectionSummaryResponse.


        :param promoter_response_status: The promoter_response_status of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionOutcomeStatusTypeResponse
        """

        self._promoter_response_status = promoter_response_status

    @property
    def promoter_response_status_string(self):
        """Gets the promoter_response_status_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response_status_string

    @promoter_response_status_string.setter
    def promoter_response_status_string(self, promoter_response_status_string):
        """Sets the promoter_response_status_string of this InspectionSummaryResponse.


        :param promoter_response_status_string: The promoter_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._promoter_response_status_string = promoter_response_status_string

    @property
    def promoter_response_status_change_date(self):
        """Gets the promoter_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._promoter_response_status_change_date

    @promoter_response_status_change_date.setter
    def promoter_response_status_change_date(self, promoter_response_status_change_date):
        """Sets the promoter_response_status_change_date of this InspectionSummaryResponse.


        :param promoter_response_status_change_date: The promoter_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._promoter_response_status_change_date = promoter_response_status_change_date

    @property
    def promoter_response_details(self):
        """Gets the promoter_response_details of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_details of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response_details

    @promoter_response_details.setter
    def promoter_response_details(self, promoter_response_details):
        """Sets the promoter_response_details of this InspectionSummaryResponse.


        :param promoter_response_details: The promoter_response_details of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._promoter_response_details = promoter_response_details

    @property
    def is_auto_accepted(self):
        """Gets the is_auto_accepted of this InspectionSummaryResponse.  # noqa: E501


        :return: The is_auto_accepted of this InspectionSummaryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_auto_accepted

    @is_auto_accepted.setter
    def is_auto_accepted(self, is_auto_accepted):
        """Sets the is_auto_accepted of this InspectionSummaryResponse.


        :param is_auto_accepted: The is_auto_accepted of this InspectionSummaryResponse.  # noqa: E501
        :type: bool
        """

        self._is_auto_accepted = is_auto_accepted

    @property
    def non_compliance_reference_number(self):
        """Gets the non_compliance_reference_number of this InspectionSummaryResponse.  # noqa: E501


        :return: The non_compliance_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._non_compliance_reference_number

    @non_compliance_reference_number.setter
    def non_compliance_reference_number(self, non_compliance_reference_number):
        """Sets the non_compliance_reference_number of this InspectionSummaryResponse.


        :param non_compliance_reference_number: The non_compliance_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._non_compliance_reference_number = non_compliance_reference_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InspectionSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
