# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HistoricFailureReasonDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failure_reason': 'FailureReason',
        'site_name': 'str',
        'details': 'str'
    }

    attribute_map = {
        'failure_reason': 'failure_reason',
        'site_name': 'site_name',
        'details': 'details'
    }

    def __init__(self, failure_reason=None, site_name=None, details=None):  # noqa: E501
        """HistoricFailureReasonDetails - a model defined in Swagger"""  # noqa: E501
        self._failure_reason = None
        self._site_name = None
        self._details = None
        self.discriminator = None
        self.failure_reason = failure_reason
        if site_name is not None:
            self.site_name = site_name
        self.details = details

    @property
    def failure_reason(self):
        """Gets the failure_reason of this HistoricFailureReasonDetails.  # noqa: E501


        :return: The failure_reason of this HistoricFailureReasonDetails.  # noqa: E501
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this HistoricFailureReasonDetails.


        :param failure_reason: The failure_reason of this HistoricFailureReasonDetails.  # noqa: E501
        :type: FailureReason
        """
        if failure_reason is None:
            raise ValueError("Invalid value for `failure_reason`, must not be `None`")  # noqa: E501

        self._failure_reason = failure_reason

    @property
    def site_name(self):
        """Gets the site_name of this HistoricFailureReasonDetails.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The site_name of this HistoricFailureReasonDetails.  # noqa: E501
        :rtype: str
        """
        return self._site_name

    @site_name.setter
    def site_name(self, site_name):
        """Sets the site_name of this HistoricFailureReasonDetails.

        Max length 100 characters  # noqa: E501

        :param site_name: The site_name of this HistoricFailureReasonDetails.  # noqa: E501
        :type: str
        """

        self._site_name = site_name

    @property
    def details(self):
        """Gets the details of this HistoricFailureReasonDetails.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The details of this HistoricFailureReasonDetails.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this HistoricFailureReasonDetails.

        Max length 500 characters  # noqa: E501

        :param details: The details of this HistoricFailureReasonDetails.  # noqa: E501
        :type: str
        """
        if details is None:
            raise ValueError("Invalid value for `details`, must not be `None`")  # noqa: E501

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HistoricFailureReasonDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricFailureReasonDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
