# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GeographicalareasGeographicalAreaReferenceNumberBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file': 'str',
        'geographical_area_reference_number': 'str',
        'internal_user_identifier': 'str',
        'internal_user_name': 'str'
    }

    attribute_map = {
        'file': 'file',
        'geographical_area_reference_number': 'geographicalAreaReferenceNumber',
        'internal_user_identifier': 'internalUserIdentifier',
        'internal_user_name': 'internalUserName'
    }

    def __init__(self, file=None, geographical_area_reference_number=None, internal_user_identifier=None, internal_user_name=None):  # noqa: E501
        """GeographicalareasGeographicalAreaReferenceNumberBody - a model defined in Swagger"""  # noqa: E501
        self._file = None
        self._geographical_area_reference_number = None
        self._internal_user_identifier = None
        self._internal_user_name = None
        self.discriminator = None
        if file is not None:
            self.file = file
        if geographical_area_reference_number is not None:
            self.geographical_area_reference_number = geographical_area_reference_number
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name

    @property
    def file(self):
        """Gets the file of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The file of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param file: The file of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._file = file

    @property
    def geographical_area_reference_number(self):
        """Gets the geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._geographical_area_reference_number

    @geographical_area_reference_number.setter
    def geographical_area_reference_number(self, geographical_area_reference_number):
        """Sets the geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param geographical_area_reference_number: The geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._geographical_area_reference_number = geographical_area_reference_number

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param internal_user_identifier: The internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param internal_user_name: The internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GeographicalareasGeographicalAreaReferenceNumberBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeographicalareasGeographicalAreaReferenceNumberBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
