# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateAncillaryInfoRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'location_description': 'str',
        'ancillary_info_description': 'str',
        'ancillary_info_coordinates': 'list[object]',
        'usrns': 'list[float]',
        'ancillary_info_type': 'AncillaryInfoType'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'location_description': 'location_description',
        'ancillary_info_description': 'ancillary_info_description',
        'ancillary_info_coordinates': 'ancillary_info_coordinates',
        'usrns': 'usrns',
        'ancillary_info_type': 'ancillary_info_type'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, location_description=None, ancillary_info_description=None, ancillary_info_coordinates=None, usrns=None, ancillary_info_type=None):  # noqa: E501
        """CreateAncillaryInfoRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._location_description = None
        self._ancillary_info_description = None
        self._ancillary_info_coordinates = None
        self._usrns = None
        self._ancillary_info_type = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        if location_description is not None:
            self.location_description = location_description
        self.ancillary_info_description = ancillary_info_description
        self.ancillary_info_coordinates = ancillary_info_coordinates
        self.usrns = usrns
        self.ancillary_info_type = ancillary_info_type

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this CreateAncillaryInfoRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this CreateAncillaryInfoRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def location_description(self):
        """Gets the location_description of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 500 characters Must be provided if ancillary_info_type is anything other than portable_traffic_signals_or_other_traffic_controls  # noqa: E501

        :return: The location_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this CreateAncillaryInfoRequest.

        Max length 500 characters Must be provided if ancillary_info_type is anything other than portable_traffic_signals_or_other_traffic_controls  # noqa: E501

        :param location_description: The location_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """

        self._location_description = location_description

    @property
    def ancillary_info_description(self):
        """Gets the ancillary_info_description of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The ancillary_info_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_description

    @ancillary_info_description.setter
    def ancillary_info_description(self, ancillary_info_description):
        """Sets the ancillary_info_description of this CreateAncillaryInfoRequest.

        Max length 500 characters  # noqa: E501

        :param ancillary_info_description: The ancillary_info_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """
        if ancillary_info_description is None:
            raise ValueError("Invalid value for `ancillary_info_description`, must not be `None`")  # noqa: E501

        self._ancillary_info_description = ancillary_info_description

    @property
    def ancillary_info_coordinates(self):
        """Gets the ancillary_info_coordinates of this CreateAncillaryInfoRequest.  # noqa: E501

        Array values must be unique Each point must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point Max length of 10  # noqa: E501

        :return: The ancillary_info_coordinates of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: list[object]
        """
        return self._ancillary_info_coordinates

    @ancillary_info_coordinates.setter
    def ancillary_info_coordinates(self, ancillary_info_coordinates):
        """Sets the ancillary_info_coordinates of this CreateAncillaryInfoRequest.

        Array values must be unique Each point must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point Max length of 10  # noqa: E501

        :param ancillary_info_coordinates: The ancillary_info_coordinates of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: list[object]
        """
        if ancillary_info_coordinates is None:
            raise ValueError("Invalid value for `ancillary_info_coordinates`, must not be `None`")  # noqa: E501

        self._ancillary_info_coordinates = ancillary_info_coordinates

    @property
    def usrns(self):
        """Gets the usrns of this CreateAncillaryInfoRequest.  # noqa: E501

        Array values must be unique Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN Max length of 25  # noqa: E501

        :return: The usrns of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._usrns

    @usrns.setter
    def usrns(self, usrns):
        """Sets the usrns of this CreateAncillaryInfoRequest.

        Array values must be unique Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN Max length of 25  # noqa: E501

        :param usrns: The usrns of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: list[float]
        """
        if usrns is None:
            raise ValueError("Invalid value for `usrns`, must not be `None`")  # noqa: E501

        self._usrns = usrns

    @property
    def ancillary_info_type(self):
        """Gets the ancillary_info_type of this CreateAncillaryInfoRequest.  # noqa: E501


        :return: The ancillary_info_type of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: AncillaryInfoType
        """
        return self._ancillary_info_type

    @ancillary_info_type.setter
    def ancillary_info_type(self, ancillary_info_type):
        """Sets the ancillary_info_type of this CreateAncillaryInfoRequest.


        :param ancillary_info_type: The ancillary_info_type of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: AncillaryInfoType
        """
        if ancillary_info_type is None:
            raise ValueError("Invalid value for `ancillary_info_type`, must not be `None`")  # noqa: E501

        self._ancillary_info_type = ancillary_info_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateAncillaryInfoRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAncillaryInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
