# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ForwardPlanUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'works_coordinates': 'object',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'works_location_description': 'str',
        'description_of_work': 'str',
        'project_reference_number': 'str',
        'traffic_management_type': 'AllOfForwardPlanUpdateRequestTrafficManagementType',
        'additional_info': 'str',
        'forward_plan_asds': 'list[PermitASD]'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'works_coordinates': 'works_coordinates',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'works_location_description': 'works_location_description',
        'description_of_work': 'description_of_work',
        'project_reference_number': 'project_reference_number',
        'traffic_management_type': 'traffic_management_type',
        'additional_info': 'additional_info',
        'forward_plan_asds': 'forward_plan_asds'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, works_coordinates=None, start_date=None, end_date=None, works_location_description=None, description_of_work=None, project_reference_number=None, traffic_management_type=None, additional_info=None, forward_plan_asds=None):  # noqa: E501
        """ForwardPlanUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._works_coordinates = None
        self._start_date = None
        self._end_date = None
        self._works_location_description = None
        self._description_of_work = None
        self._project_reference_number = None
        self._traffic_management_type = None
        self._additional_info = None
        self._forward_plan_asds = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.works_coordinates = works_coordinates
        self.start_date = start_date
        self.end_date = end_date
        self.works_location_description = works_location_description
        self.description_of_work = description_of_work
        if project_reference_number is not None:
            self.project_reference_number = project_reference_number
        if traffic_management_type is not None:
            self.traffic_management_type = traffic_management_type
        if additional_info is not None:
            self.additional_info = additional_info
        if forward_plan_asds is not None:
            self.forward_plan_asds = forward_plan_asds

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this ForwardPlanUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this ForwardPlanUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this ForwardPlanUpdateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The works_coordinates of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this ForwardPlanUpdateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param works_coordinates: The works_coordinates of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def start_date(self):
        """Gets the start_date of this ForwardPlanUpdateRequest.  # noqa: E501


        :return: The start_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ForwardPlanUpdateRequest.


        :param start_date: The start_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ForwardPlanUpdateRequest.  # noqa: E501

        end_date must be on or after start_date  # noqa: E501

        :return: The end_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ForwardPlanUpdateRequest.

        end_date must be on or after start_date  # noqa: E501

        :param end_date: The end_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def works_location_description(self):
        """Gets the works_location_description of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The works_location_description of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this ForwardPlanUpdateRequest.

        Max length 500 characters  # noqa: E501

        :param works_location_description: The works_location_description of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def description_of_work(self):
        """Gets the description_of_work of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The description_of_work of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this ForwardPlanUpdateRequest.

        Max length 500 characters  # noqa: E501

        :param description_of_work: The description_of_work of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """
        if description_of_work is None:
            raise ValueError("Invalid value for `description_of_work`, must not be `None`")  # noqa: E501

        self._description_of_work = description_of_work

    @property
    def project_reference_number(self):
        """Gets the project_reference_number of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The project_reference_number of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_reference_number

    @project_reference_number.setter
    def project_reference_number(self, project_reference_number):
        """Sets the project_reference_number of this ForwardPlanUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param project_reference_number: The project_reference_number of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._project_reference_number = project_reference_number

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this ForwardPlanUpdateRequest.  # noqa: E501


        :return: The traffic_management_type of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: AllOfForwardPlanUpdateRequestTrafficManagementType
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this ForwardPlanUpdateRequest.


        :param traffic_management_type: The traffic_management_type of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: AllOfForwardPlanUpdateRequestTrafficManagementType
        """

        self._traffic_management_type = traffic_management_type

    @property
    def additional_info(self):
        """Gets the additional_info of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The additional_info of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this ForwardPlanUpdateRequest.

        Max length 500 characters  # noqa: E501

        :param additional_info: The additional_info of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def forward_plan_asds(self):
        """Gets the forward_plan_asds of this ForwardPlanUpdateRequest.  # noqa: E501


        :return: The forward_plan_asds of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: list[PermitASD]
        """
        return self._forward_plan_asds

    @forward_plan_asds.setter
    def forward_plan_asds(self, forward_plan_asds):
        """Sets the forward_plan_asds of this ForwardPlanUpdateRequest.


        :param forward_plan_asds: The forward_plan_asds of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: list[PermitASD]
        """

        self._forward_plan_asds = forward_plan_asds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForwardPlanUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForwardPlanUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
